% Altered on 12 June 2021; KoverC_Moon_coremantledissipation is no longer taken from EarthMoon_constants, but is a separate input because it changes over time

% This code computes the power dissipation due to tides in the Moon,
%   based on the proportionality between this dissipation and da/dt
%   due to tides within the Moon, as disussed by Jim Williams in 
%   November 2020

% The code also computes the power dissipation due to the lunar
%   core-mantle boundary

% The code also compares both of these dissipations to other tidal 
%   dissipations within the Earth-Moon system

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Load parameters for the present-day:

load parameters_presentday_v9_use_structures_nodeLF.mat

% Extract present-day parameter and orbital parameter values:

omega_E=PresentDayValues_orbitalparameters.omega_E_presentday;
a=PresentDayValues_orbitalparameters.a_presentday;
inclination=PresentDayValues_orbitalparameters.inclination_presentday;
eccentricity=PresentDayValues_orbitalparameters.eccentricity_presentday;
epsilon=PresentDayValues_orbitalparameters.epsilon_presentday;
n=PresentDayValues_orbitalparameters.n_presentday;

nprime=EarthMoon_constants.nprime;
%KoverC_Moon_coremantledissipation=EarthMoon_constants.KoverC_Moon_coremantledissipation;
CoverCprime_Moon_coremantledissipation=EarthMoon_constants.CoverCprime_Moon_coremantledissipation;

% Compute dOmega_dt, I_lunartilt, and xi_Moon_coremantledissipation:

[dOmega_dt] = compute_noderate(nprime,n);

[I_lunartilt] = compute_lunarequatorialtilt_WardEquation(dOmega_dt,inclination,n,EarthMoon_constants);

% Check value of I_lunartilt, in degrees:
I_lunartilt*(360/(2*pi))
% answer 1.5704 degrees; Williams writeup says 1.543 degrees

[KoverC_Moon_coremantledissipation,xi_Moon_coremantledissipation] = compute_KoverC_and_xi_lunarCMB(CoverCprime_Moon_coremantledissipation,dOmega_dt,n,I_lunartilt);

xi_Moon_coremantledissipation
% answer 0.0226

KoverC_Moon_coremantledissipation
% answer 9.6731e-14

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% First, compute the power dissipation due to tides within the Moon:

[da_dt_tidesinMoon,da_dt_Moon_coremantledissipation] = compute_da_dt_tidesinMoon2(EarthMoon_constants,a,n,eccentricity,inclination,I_lunartilt,KoverC_Moon_coremantledissipation,xi_Moon_coremantledissipation);

% Check value of da_dt, in units of mm/year:
da_dt_tidesinMoon * 1000 * ( (86400*365.25) )
% answer -0.3865

[power_dissipation_tidesinMoon] = compute_powerdissipation_tidesinMoon(da_dt_tidesinMoon,a,EarthMoon_constants);

power_dissipation_tidesinMoon
% answer -1.2135e+09

% What would we have gotten for the latter number if we had used 
%   Jim Williams number for da/dt due to tides within the Moon?

power_dissipation_tidesinMoon*0.471/0.3865
% answer -1.4789e+09

% We can round off the two answers to about 1.2-1.5 GW

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Next, compute the power dissipation due to the lunar core-mantle boundary:

[power_dissipation_lunarcoremantleboundary] = compute_powerdissipation_Moon_coremantleboundary(EarthMoon_constants,n,I_lunartilt,KoverC_Moon_coremantledissipation,xi_Moon_coremantledissipation);

power_dissipation_lunarcoremantleboundary
% answer 4.4850e+07 

% Compute ratio of lunar core-mantle boundary dissipation to the 
%   dissipation due to tides in Moon:

power_dissipation_lunarcoremantleboundary/power_dissipation_tidesinMoon
%  answer -0.0370 i.e. 4.0%

power_dissipation_tidesinMoon/power_dissipation_lunarcoremantleboundary
%  answer -27.0580


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Jim says that the power dissipation due to tides in the Moon is 0.8%
%   of the total (Earth plus Moon) dissipation rate transferred into the 
%   orbit

% Let us check this:
%   The dissipation rate transferred into the orbit is proportional to
%   da/dt.  Let us use the same code that we used to compute the 
%   dissipation rate due to tides in the Moon, but with da/dt replaced
%   by the present-day da/dt due to all effects (3.8 cm/year):

da_dt_total = 3.8 * (10^-2) / (365.25*86400);

[power_dissipation_total_transferred_into_orbit] = compute_powerdissipation_tidesinMoon(da_dt_total,a,EarthMoon_constants);

power_dissipation_total_transferred_into_orbit
% answer 1.1931e+11

100*power_dissipation_tidesinMoon/power_dissipation_total_transferred_into_orbit
% answer -1.0171 -- thus, rounded off to 1.0%, slightly higher than I had before

% This is, of course, equal to the ratio of the separate da/dt values:

100*0.3865/38
% answer 1.0171

% All of the above is based upon our computed rate of da/dt due to tides
%   in Moon.  What if we had instead used the more accurate da/da rate, due 
%   to tides within the Moon, that we obtained from Jim Williams?

100*0.471/38
% answer 1.2395 -- thus, rounds off to 1.2%

% Next, we compare the total dissipation rate transferred into the orbit, 
%   with the total dissipation rate due to all tidal processes on the Earth
%   and Moon:

100*power_dissipation_total_transferred_into_orbit/(3.7*10^12)
% answer 3.2247 -- thus, about 3%, as we wrote before

% All of this implies that the dissipation due to tides in the Moon
%   is 

0.012395 * 0.032247
% 3.9970e-04

% of the total dissipation rate due to all tidal processes on the Earth
%   and Moon

% In percentage terms, the latter number is
100*0.012395 * 0.032247
% answer 0.04


