% Re-run 13 June 2021, after the "v9" version of the parameter structure was 
%   generated

% Re-run 24 December 2020 and 8 February 2021, after v8 stuctures are in place

% Re-run 19 July 2020, after semidiurnal node and L+F astronomical forcing amplitudes were changed and diurnal node body tide k sin chi value was changed

% Computes da_dt rates for all of the constituents of interest 
%                         including for the node and L+F terms

% Load parameters for the present-day:

load parameters_presentday_v9_use_structures_nodeLF.mat

% Set a, aprime, eccentricityprime, inclination, eccentricity, epsilon, n, nprime, and S_E
%      to the present-day values:

omega_E=PresentDayValues_orbitalparameters.omega_E_presentday;
a=PresentDayValues_orbitalparameters.a_presentday;
inclination=PresentDayValues_orbitalparameters.inclination_presentday;
eccentricity=PresentDayValues_orbitalparameters.eccentricity_presentday;
epsilon=PresentDayValues_orbitalparameters.epsilon_presentday;
n=PresentDayValues_orbitalparameters.n_presentday;

aprime=EarthMoon_constants.aprime;
eccentricityprime=EarthMoon_constants.eccentricityprime;
nprime=EarthMoon_constants.nprime;
G=EarthMoon_constants.G;
k2fluid=EarthMoon_constants.k2fluid;
sfluid=EarthMoon_constants.sfluid;
M_E=EarthMoon_constants.M_E;
R=EarthMoon_constants.R;
C_0=EarthMoon_constants.C_0;
M_S=EarthMoon_constants.M_S;
M_M=EarthMoon_constants.M_M;

vector_longperiod_oneplusdelta_q0=ConstituentIndexParameters.vector_longperiod_oneplusdelta_q0;
vector_longperiod_jM=ConstituentIndexParameters.vector_longperiod_jM;
vector_longperiod_jW=ConstituentIndexParameters.vector_longperiod_jW;
vector_longperiod_jOmega=ConstituentIndexParameters.vector_longperiod_jOmega;
vector_longperiod_ksinchi_bodytide=ksinchi_vectors.vector_longperiod_ksinchi_bodytide;
vector_longperiod_ksinchi_oceantide=ksinchi_vectors.vector_longperiod_ksinchi_oceantide;

vector_diurnal_oneplusdelta_q0=ConstituentIndexParameters.vector_diurnal_oneplusdelta_q0;
vector_diurnal_qfactor=ConstituentIndexParameters.vector_diurnal_qfactor;
vector_longperiod_qfactor=ConstituentIndexParameters.vector_longperiod_qfactor;
vector_diurnal_jM=ConstituentIndexParameters.vector_diurnal_jM;
vector_diurnal_jW=ConstituentIndexParameters.vector_diurnal_jW;
vector_diurnal_jOmega=ConstituentIndexParameters.vector_diurnal_jOmega;
vector_diurnal_ksinchi_bodytide=ksinchi_vectors.vector_diurnal_ksinchi_bodytide;
vector_diurnal_ksinchi_oceantide=ksinchi_vectors.vector_diurnal_ksinchi_oceantide;

vector_semidiurnal_oneplusdelta_q0=ConstituentIndexParameters.vector_semidiurnal_oneplusdelta_q0;
vector_semidiurnal_qfactor=ConstituentIndexParameters.vector_semidiurnal_qfactor;
vector_semidiurnal_jM=ConstituentIndexParameters.vector_semidiurnal_jM;
vector_semidiurnal_jW=ConstituentIndexParameters.vector_semidiurnal_jW;
vector_semidiurnal_jOmega=ConstituentIndexParameters.vector_semidiurnal_jOmega;
vector_semidiurnal_ksinchi_bodytide=ksinchi_vectors.vector_semidiurnal_ksinchi_bodytide;
vector_semidiurnal_ksinchi_oceantide=ksinchi_vectors.vector_semidiurnal_ksinchi_oceantide;

% Compute S_E, S_A, S_W and C_of_omega_E:

S_E = compute_S_E(n,nprime);
S_A = compute_S_A(n,nprime);
[S_W]=compute_S_W(omega_E,k2fluid,sfluid);
[C_of_omega_E]=compute_C_of_omega_E(omega_E,k2fluid,sfluid,M_E,R,C_0);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Long-period tides

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Compute U11plusU22minus2U33 values for the long period tides:

[U11plusU22minus2U33_constant_lunarpart,U11plusU22minus2U33_constant_solarpart,U11plusU22minus2U33_Mf,U11plusU22minus2U33_Mm]=computeUcombinations_longperiodtides(inclination,eccentricity,epsilon,M_S,a,M_M,aprime,eccentricityprime);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Create vector of long-period U11plusU22minus2U33 values, omitting the "CONSTANT" term:

vector_longperiod_U11plusU22minus2U33=[U11plusU22minus2U33_Mf U11plusU22minus2U33_Mm];

%%%%%

% Compute long-period body and ocean tide da_dt terms:

vector_longperiod_bodytide_da_dt=[];
vector_longperiod_oceantide_da_dt=[];

for m=1:length(vector_longperiod_U11plusU22minus2U33)
  U11plusU22minus2U33=vector_longperiod_U11plusU22minus2U33(m);
  oneplusdelta_q0=vector_longperiod_oneplusdelta_q0(m);
  jM=vector_longperiod_jM(m);

  % body tide contribution

  ksinchi=vector_longperiod_ksinchi_bodytide(m);
  [dummy]=compute_da_dt_longperiod(n,a,S_A,M_M,M_E,R,jM,U11plusU22minus2U33,ksinchi);
  vector_longperiod_bodytide_da_dt=[vector_longperiod_bodytide_da_dt dummy];
  clear ksinchi dummy

  % ocean tide contribution

  ksinchi=vector_longperiod_ksinchi_oceantide(m);
  [dummy]=compute_da_dt_longperiod(n,a,S_A,M_M,M_E,R,jM,U11plusU22minus2U33,ksinchi);
  vector_longperiod_oceantide_da_dt=[vector_longperiod_oceantide_da_dt dummy];
  clear ksinchi dummy

  clear U11plusU22minus2U33 oneplusdelta_q0 jM
end

% Add body and ocean tide contributions, and convert to units used in Table 7 of Williams and Boggs (2016)--mm/year:

(vector_longperiod_bodytide_da_dt+vector_longperiod_oceantide_da_dt) * 1000 * ( (86400*365.25) )

% answer -0.1610 -0.0178 
%which agree pretty well with Jims new Table values if the latter are multiplied by ksinchi:
[-13.523 -1.974].*(vector_longperiod_ksinchi_bodytide+vector_longperiod_ksinchi_oceantide)
% answer -0.1609 -0.0178

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Diurnal tides

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Compute U13minusU23 values for the diurnal tides:

[U13minusU23_K1_lunarpart,U13minusU23_K1_solarpart,U13minusU23_O1,U13minusU23_P1,U13minusU23_Q1,U13minusU23_diurnal_node,U13minusU23_diurnal_LF]=computeUcombinations_diurnaltides_nodeLF(inclination,eccentricity,epsilon,M_S,a,M_M,aprime,eccentricityprime);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Create vector of diurnal U13minusU23 values, adding the lunar and solar parts for K1:

vector_diurnal_U13minusU23=[U13minusU23_K1_lunarpart+U13minusU23_K1_solarpart U13minusU23_O1 U13minusU23_P1 U13minusU23_Q1 U13minusU23_diurnal_node U13minusU23_diurnal_LF];

%%%%%

% Compute diurnal body and ocean tide da_dt terms:

vector_diurnal_bodytide_da_dt=[];
vector_diurnal_oceantide_da_dt=[];

for m=1:length(vector_diurnal_U13minusU23)
  U13minusU23=vector_diurnal_U13minusU23(m);
  oneplusdelta_q0=vector_diurnal_oneplusdelta_q0(m);
  jM=vector_diurnal_jM(m);

  % body tide contribution

  ksinchi=vector_diurnal_ksinchi_bodytide(m);
  [dummy]=compute_da_dt_diurnal(n,a,S_A,M_M,M_E,R,jM,U13minusU23,ksinchi);
  vector_diurnal_bodytide_da_dt=[vector_diurnal_bodytide_da_dt dummy];
  clear ksinchi dummy

  % ocean tide contribution

  ksinchi=vector_diurnal_ksinchi_oceantide(m);
  [dummy]=compute_da_dt_diurnal(n,a,S_A,M_M,M_E,R,jM,U13minusU23,ksinchi);
  vector_diurnal_oceantide_da_dt=[vector_diurnal_oceantide_da_dt dummy];
  clear ksinchi dummy

  clear U13minusU23 oneplusdelta_q0 jM
end

% Add body and ocean tide contributions, and convert to units used in Table 7 of Williams and Boggs (2016)--mm/year:

(vector_diurnal_bodytide_da_dt+vector_diurnal_oceantide_da_dt) * 1000 * ( (86400*365.25) )

% answer 0    4.9763         0    0.2832         0    0.1805
%which agree pretty well with Jims new Table values if the latter are multiplied by ksinchi:
[0 212.644 0 11.798 0 7.713].*(vector_diurnal_ksinchi_bodytide+vector_diurnal_ksinchi_oceantide)
% answer 0    4.9759         0    0.2832         0    0.1805

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Semidiurnal tides

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Compute U11minusU22plus2U12 values for the semidiurnal tides:

[U11minusU22plus2U12_K2_lunarpart,U11minusU22plus2U12_K2_solarpart,U11minusU22plus2U12_M2,U11minusU22plus2U12_S2,U11minusU22plus2U12_N2,U11minusU22plus2U12_semidiurnal_node,U11minusU22plus2U12_semidiurnal_LF]=computeUcombinations_semidiurnaltides_nodeLF(inclination,eccentricity,epsilon,M_S,a,M_M,aprime,eccentricityprime);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Create vector of semidiurnal U11minusU22plus2U12 values, adding the lunar and solar parts for K2:

vector_semidiurnal_U11minusU22plus2U12=[U11minusU22plus2U12_K2_lunarpart+U11minusU22plus2U12_K2_solarpart U11minusU22plus2U12_M2 U11minusU22plus2U12_S2 U11minusU22plus2U12_N2 U11minusU22plus2U12_semidiurnal_node U11minusU22plus2U12_semidiurnal_LF];

%%%%%

% Compute semidiurnal body and ocean tide da_dt terms:

vector_semidiurnal_bodytide_da_dt=[];
vector_semidiurnal_oceantide_da_dt=[];

for m=1:length(vector_semidiurnal_U11minusU22plus2U12)
  U11minusU22plus2U12=vector_semidiurnal_U11minusU22plus2U12(m);
  oneplusdelta_q0=vector_semidiurnal_oneplusdelta_q0(m);
  jM=vector_semidiurnal_jM(m);

  % body tide contribution

  ksinchi=vector_semidiurnal_ksinchi_bodytide(m);
  [dummy]=compute_da_dt_semidiurnal(n,a,S_A,M_M,M_E,R,jM,U11minusU22plus2U12,ksinchi);
  vector_semidiurnal_bodytide_da_dt=[vector_semidiurnal_bodytide_da_dt dummy];
  clear ksinchi dummy

  % ocean tide contribution

  ksinchi=vector_semidiurnal_ksinchi_oceantide(m);
  [dummy]=compute_da_dt_semidiurnal(n,a,S_A,M_M,M_E,R,jM,U11minusU22plus2U12,ksinchi);
  vector_semidiurnal_oceantide_da_dt=[vector_semidiurnal_oceantide_da_dt dummy];
  clear ksinchi dummy

  clear U11minusU22plus2U12 oneplusdelta_q0 jM
end

% Add body and ocean tide contributions, and convert to units used in Table 7 of Williams and Boggs (2016)--mm/year:

(vector_semidiurnal_bodytide_da_dt+vector_semidiurnal_oceantide_da_dt) * 1000 * ( (86400*365.25) )

% answer 0   31.3472         0    2.2332         0    0.0429
%which agree pretty well with Jims new Table values if the latter are multiplied by ksinchi:
[0 1253.863 0 69.57 0 1.717].*(vector_semidiurnal_ksinchi_bodytide+vector_semidiurnal_ksinchi_oceantide)
% answer 0   31.3466         0    2.2332         0    0.0429
