% Re-run 13 June 2021, after the "v9" version of the parameter structure was 
%   generated

% Re-run 24 December 2020 and 8 February 2021, after v8 stuctures are in place

% Re-run 19 July 2020, after semidiurnal node and L+F astronomical forcing amplitudes were changed and diurnal node body tide k sin chi value was changed

% Computes domega_E_dt rates for all of the constituents of interest 
%                         including for the node and L+F terms

% Load parameters for the present-day:

load parameters_presentday_v9_use_structures_nodeLF.mat

% Set a, aprime, eccentricityprime, inclination, eccentricity, epsilon, n, nprime, and S_E
%      to the present-day values:

omega_E=PresentDayValues_orbitalparameters.omega_E_presentday;
a=PresentDayValues_orbitalparameters.a_presentday;
inclination=PresentDayValues_orbitalparameters.inclination_presentday;
eccentricity=PresentDayValues_orbitalparameters.eccentricity_presentday;
epsilon=PresentDayValues_orbitalparameters.epsilon_presentday;
n=PresentDayValues_orbitalparameters.n_presentday;

aprime=EarthMoon_constants.aprime;
eccentricityprime=EarthMoon_constants.eccentricityprime;
nprime=EarthMoon_constants.nprime;
G=EarthMoon_constants.G;
k2fluid=EarthMoon_constants.k2fluid;
sfluid=EarthMoon_constants.sfluid;
M_E=EarthMoon_constants.M_E;
R=EarthMoon_constants.R;
C_0=EarthMoon_constants.C_0;
M_S=EarthMoon_constants.M_S;
M_M=EarthMoon_constants.M_M;

vector_longperiod_oneplusdelta_q0=ConstituentIndexParameters.vector_longperiod_oneplusdelta_q0;
vector_longperiod_qfactor=ConstituentIndexParameters.vector_longperiod_qfactor;
vector_longperiod_jM=ConstituentIndexParameters.vector_longperiod_jM;
vector_longperiod_jW=ConstituentIndexParameters.vector_longperiod_jW;
vector_longperiod_jOmega=ConstituentIndexParameters.vector_longperiod_jOmega;
vector_longperiod_ksinchi_bodytide=ksinchi_vectors.vector_longperiod_ksinchi_bodytide;
vector_longperiod_ksinchi_oceantide=ksinchi_vectors.vector_longperiod_ksinchi_oceantide;

vector_diurnal_oneplusdelta_q0=ConstituentIndexParameters.vector_diurnal_oneplusdelta_q0;
vector_diurnal_qfactor=ConstituentIndexParameters.vector_diurnal_qfactor;
vector_diurnal_jM=ConstituentIndexParameters.vector_diurnal_jM;
vector_diurnal_jW=ConstituentIndexParameters.vector_diurnal_jW;
vector_diurnal_jOmega=ConstituentIndexParameters.vector_diurnal_jOmega;
vector_diurnal_ksinchi_bodytide=ksinchi_vectors.vector_diurnal_ksinchi_bodytide;
vector_diurnal_ksinchi_oceantide=ksinchi_vectors.vector_diurnal_ksinchi_oceantide;

vector_semidiurnal_oneplusdelta_q0=ConstituentIndexParameters.vector_semidiurnal_oneplusdelta_q0;
vector_semidiurnal_qfactor=ConstituentIndexParameters.vector_semidiurnal_qfactor;
vector_semidiurnal_jM=ConstituentIndexParameters.vector_semidiurnal_jM;
vector_semidiurnal_jW=ConstituentIndexParameters.vector_semidiurnal_jW;
vector_semidiurnal_jOmega=ConstituentIndexParameters.vector_semidiurnal_jOmega;
vector_semidiurnal_ksinchi_bodytide=ksinchi_vectors.vector_semidiurnal_ksinchi_bodytide;
vector_semidiurnal_ksinchi_oceantide=ksinchi_vectors.vector_semidiurnal_ksinchi_oceantide;

% Compute S_E, S_A, S_W and C_of_omega_E:

S_E = compute_S_E(n,nprime);
S_A = compute_S_A(n,nprime);
[S_W]=compute_S_W(omega_E,k2fluid,sfluid);
[C_of_omega_E]=compute_C_of_omega_E(omega_E,k2fluid,sfluid,M_E,R,C_0);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Diurnal tides

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Compute U13minusU23 values for the diurnal tides:

[U13minusU23_K1_lunarpart,U13minusU23_K1_solarpart,U13minusU23_O1,U13minusU23_P1,U13minusU23_Q1,U13minusU23_diurnal_node,U13minusU23_diurnal_LF]=computeUcombinations_diurnaltides_nodeLF(inclination,eccentricity,epsilon,M_S,a,M_M,aprime,eccentricityprime);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Create vector of diurnal U13minusU23 values, adding the lunar and solar parts for K1:

vector_diurnal_U13minusU23=[U13minusU23_K1_lunarpart+U13minusU23_K1_solarpart U13minusU23_O1 U13minusU23_P1 U13minusU23_Q1 U13minusU23_diurnal_node U13minusU23_diurnal_LF];

%%%%%

% Compute diurnal body and ocean tide domega_E_dt terms:

vector_diurnal_bodytide_domega_E_dt=[];
vector_diurnal_oceantide_domega_E_dt=[];

for m=1:length(vector_diurnal_U13minusU23)
  U13minusU23=vector_diurnal_U13minusU23(m);
  oneplusdelta_q0=vector_diurnal_oneplusdelta_q0(m);
  qfactor=vector_diurnal_qfactor(m);
  jM=vector_diurnal_jM(m);

  % body tide contribution

  ksinchi=vector_diurnal_ksinchi_bodytide(m);
  [dummy]=compute_domega_E_dt_diurnal(G,M_M,M_E,a,R,S_W,C_of_omega_E,oneplusdelta_q0,qfactor,U13minusU23,ksinchi);
  vector_diurnal_bodytide_domega_E_dt=[vector_diurnal_bodytide_domega_E_dt dummy];
  clear ksinchi dummy

  % ocean tide contribution

  ksinchi=vector_diurnal_ksinchi_oceantide(m);
  [dummy]=compute_domega_E_dt_diurnal(G,M_M,M_E,a,R,S_W,C_of_omega_E,oneplusdelta_q0,qfactor,U13minusU23,ksinchi);
  vector_diurnal_oceantide_domega_E_dt=[vector_diurnal_oceantide_domega_E_dt dummy];
  clear ksinchi dummy

  clear U13minusU23 oneplusdelta_q0 qfactor jM
end

% Add body and ocean tide contributions, and convert to units used in Table 7 of Williams and Boggs (2016)--arcseconds/(century^2):

(vector_diurnal_bodytide_domega_E_dt+vector_diurnal_oceantide_domega_E_dt)*(360/(2*pi))*60*60*( (86400*365.25*100)^2 )
% answer -93.6976  -73.8377  -11.3851   -2.8012   -1.7164   -2.6778
%which agrees pretty well with Jims new Table values if the latter are multiplied by ksinchi:
[-6265 -3169 -683 -117 -117 -115].*(vector_diurnal_ksinchi_bodytide+vector_diurnal_ksinchi_oceantide)
% answer -93.9750  -74.1546  -11.4744   -2.8080   -1.7199   -2.6910

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Semidiurnal tides

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Compute U11minusU22plus2U12 values for the semidiurnal tides:

[U11minusU22plus2U12_K2_lunarpart,U11minusU22plus2U12_K2_solarpart,U11minusU22plus2U12_M2,U11minusU22plus2U12_S2,U11minusU22plus2U12_N2,U11minusU22plus2U12_semidiurnal_node,U11minusU22plus2U12_semidiurnal_LF]=computeUcombinations_semidiurnaltides_nodeLF(inclination,eccentricity,epsilon,M_S,a,M_M,aprime,eccentricityprime);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Create vector of semidiurnal U11minusU22plus2U12 values, adding the lunar and solar parts for K2:

vector_semidiurnal_U11minusU22plus2U12=[U11minusU22plus2U12_K2_lunarpart+U11minusU22plus2U12_K2_solarpart U11minusU22plus2U12_M2 U11minusU22plus2U12_S2 U11minusU22plus2U12_N2 U11minusU22plus2U12_semidiurnal_node U11minusU22plus2U12_semidiurnal_LF];

%%%%%

% Compute semidiurnal body and ocean tide domega_E_dt terms:

vector_semidiurnal_bodytide_domega_E_dt=[];
vector_semidiurnal_oceantide_domega_E_dt=[];

for m=1:length(vector_semidiurnal_U11minusU22plus2U12)
  U11minusU22plus2U12=vector_semidiurnal_U11minusU22plus2U12(m);
  oneplusdelta_q0=vector_semidiurnal_oneplusdelta_q0(m);
  qfactor=vector_semidiurnal_qfactor(m);
  jM=vector_semidiurnal_jM(m);

  % body tide contribution

  ksinchi=vector_semidiurnal_ksinchi_bodytide(m);
  [dummy]=compute_domega_E_dt_semidiurnal(G,M_M,M_E,a,R,S_W,C_of_omega_E,oneplusdelta_q0,qfactor,U11minusU22plus2U12,ksinchi);
  vector_semidiurnal_bodytide_domega_E_dt=[vector_semidiurnal_bodytide_domega_E_dt dummy];
  clear ksinchi dummy

  % ocean tide contribution

  ksinchi=vector_semidiurnal_ksinchi_oceantide(m);
  [dummy]=compute_domega_E_dt_semidiurnal(G,M_M,M_E,a,R,S_W,C_of_omega_E,oneplusdelta_q0,qfactor,U11minusU22plus2U12,ksinchi);
  vector_semidiurnal_oceantide_domega_E_dt=[vector_semidiurnal_oceantide_domega_E_dt dummy];
  clear ksinchi dummy

  clear U11minusU22plus2U12 oneplusdelta_q0 qfactor jM
end

% Add body and ocean tide contributions, and convert to units used in Table 7 of Williams and Boggs (2016)--arcseconds/(century^2):

(vector_semidiurnal_bodytide_domega_E_dt+vector_semidiurnal_oceantide_domega_E_dt)*(360/(2*pi))*60*60*( (86400*365.25*100)^2 )
% answer -10.8600 -930.2477 -147.0424  -44.1813   -0.9775   -1.2739
%which agrees pretty well with Jims new Table values if the latter are multiplied by ksinchi:
[-579 -37371 -8058 -1382 -52 -51].*(vector_semidiurnal_ksinchi_bodytide+vector_semidiurnal_ksinchi_oceantide)
% answer -10.8852 -934.2750 -148.2672  -44.3622   -0.9776   -1.2750 
