% Altered on 12 June 2021; KoverC_Moon_coremantledissipation is no longer taken from EarthMoon_constants, but is a separate input because it changes over time

% Rewritten on 24 December 2020 and 8 February 2021 to account for new "tidesinMoon2" codes

% Computes several quantities associated with the impact of tides in the Moon

% Load parameters for the present-day:

load parameters_presentday_v9_use_structures_nodeLF.mat

% Set nprime and two core-mantle boundary variables 
%      to the present-day values (note that this is neccessary
%      because some of the codes used below have not been changed to
%      use EarthMoon_constants):

nprime=EarthMoon_constants.nprime;
%KoverC_Moon_coremantledissipation=EarthMoon_constants.KoverC_Moon_coremantledissipation;
CoverCprime_Moon_coremantledissipation=EarthMoon_constants.CoverCprime_Moon_coremantledissipation;

% Extract values of present-day orbital parameters:

omega_E=PresentDayValues_orbitalparameters.omega_E_presentday;
a=PresentDayValues_orbitalparameters.a_presentday;
inclination=PresentDayValues_orbitalparameters.inclination_presentday;
eccentricity=PresentDayValues_orbitalparameters.eccentricity_presentday;
epsilon=PresentDayValues_orbitalparameters.epsilon_presentday;
n=PresentDayValues_orbitalparameters.n_presentday;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Compute dOmega_dt, I_lunartilt, and xi_Moon_coremantledissipation:

[dOmega_dt] = compute_noderate(nprime,n);


%[I_lunartilt] = compute_lunarequatorialtilt(dOmega_dt,inclination,beta_tidesinMoon,n,c);
[I_lunartilt] = compute_lunarequatorialtilt_WardEquation(dOmega_dt,inclination,n,EarthMoon_constants);


% Check value of I_lunartilt, in degrees:
I_lunartilt*(360/(2*pi))
% answer 1.5704 degrees; Williams writeup says 1.543 degrees

[KoverC_Moon_coremantledissipation,xi_Moon_coremantledissipation] = compute_KoverC_and_xi_lunarCMB(CoverCprime_Moon_coremantledissipation,dOmega_dt,n,I_lunartilt);

[dinclination_dt_tidesinMoon,dinclination_dt_Moon_coremantledissipation] = compute_dinclination_dt_tidesinMoon2(EarthMoon_constants,a,n,eccentricity,inclination,I_lunartilt,KoverC_Moon_coremantledissipation,xi_Moon_coremantledissipation);
% Check values of dinclination_dt, in units of microarcseconds/year:
dinclination_dt_tidesinMoon * ( 10^6 ) * (360/(2*pi))*60*60*( (86400*365.25) )
% answer -0.4587
% Compare to -0.51 microarcseconds per year in Jim Williams comments on 12/31/2020 paper draft

dinclination_dt_Moon_coremantledissipation * ( 10^6 ) * (360/(2*pi))*60*60*( (86400*365.25) )
% answer -0.0429
% Compare to -0.04 microarcseconds per year in Jim Williams comments on 12/31/2020 paper draft

[deccentricity_dt_tidesinMoon] = compute_deccentricity_dt_tidesinMoon2(EarthMoon_constants,a,n,eccentricity,inclination,I_lunartilt);
% Check value of deccentricity_dt, in units of 1 * 10^-12/year:
deccentricity_dt_tidesinMoon * (10^12) * ( (86400*365.25) )
% answer -5.4936
 % Compare to -6.9 e-12 per year in Jim Williams comments on 12/31/2020 paper draft, with a 0 contribution from CMB


[da_dt_tidesinMoon,da_dt_Moon_coremantledissipation] = compute_da_dt_tidesinMoon2(EarthMoon_constants,a,n,eccentricity,inclination,I_lunartilt,KoverC_Moon_coremantledissipation,xi_Moon_coremantledissipation);
% Check value of da_dt, in units of mm/year:
da_dt_tidesinMoon * 1000 * ( (86400*365.25) )
% answer -0.3865
% Compare to -0.471 mm/year in Jim Williams comments on 12/31/2020 paper draft
da_dt_Moon_coremantledissipation * 1000 * ( (86400*365.25) )
% answer -0.0143
% Compare to -0.015 mm/year in Jim Williams comments on 12/31/2020 paper draft

