% Re-run 12 June 2021, after v9 structures are in place

% Re-run 24 December 2020 and 8 February 2021, after v8 stuctures are in place

% Load parameters for the present-day:

load parameters_presentday_v9_use_structures.mat 

% Set parameters to the present-day values:

omega_E=PresentDayValues_orbitalparameters.omega_E_presentday;
a=PresentDayValues_orbitalparameters.a_presentday;
inclination=PresentDayValues_orbitalparameters.inclination_presentday;
eccentricity=PresentDayValues_orbitalparameters.eccentricity_presentday;
epsilon=PresentDayValues_orbitalparameters.epsilon_presentday;
n=PresentDayValues_orbitalparameters.n_presentday;

aprime=EarthMoon_constants.aprime;
eccentricityprime=EarthMoon_constants.eccentricityprime;
nprime=EarthMoon_constants.nprime;

% Compute node rate:

[dOmega_dt] = compute_noderate(nprime,n);

% Compute longitude of perigee rate:

[domegabar_dt] = compute_longitudeofperigeerate(nprime,n);

% Set value of dl_dt:

dl_dt = n - domegabar_dt;

% Set dlprime_dt (see December 3, 2017 Williams email but change units from arcseconds per year to radians per second):

dlprime_dt = 1295965.8 * ( 1 / 3600 ) * ( 2 * pi / 360 ) * ( 1 / (86400*365.25) );
% Check against row 14 in Table 3 of Williams and Boggs 2016:
(2*pi/dlprime_dt)*(1/86400)
% answer 365.2596 days
% Agrees with 365.2596 day period in Williams and Boggs Table 3

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Check present-day tidal frequencies (units radians per second):

frequency_Mf = 2*n
% answer 5.3234e-06 
% Agrees with 0.053234e-04 value from Table 1 in Arbic et al. (2004) DSR2 paper

frequency_Mm = dl_dt
% answer 2.6392e-06
% Agrees with 0.026392e-04 value from Table 1 in Arbic et al. (2004) DSR2 paper

frequency_K1 = omega_E
% answer 7.2921e-05
% Agrees with 0.7292117e-04 value from Table 1 in Arbic et al. (2004) DSR2 paper

frequency_O1 = omega_E - 2*n
% answer 6.7598e-05
% Agrees with 0.6759774e-04 value from Table 1 in Arbic et al. (2004) DSR2 paper

frequency_P1 = omega_E - 2*nprime
% answer 7.2523e-05
% Agrees with 0.7252295e-04 value from Table 1 in Arbic et al. (2004) DSR2 paper

frequency_Q1 = omega_E - 2*n - dl_dt
% answer 6.4959e-05
% Agrees with 0.6495854e-04 value from Table 1 in Arbic et al. (2004) DSR2 paper 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

frequency_K2 = 2*omega_E
% answer 1.4584e-04
% Agrees with 1.458423e-4 value from Table 1 in Arbic et al. (2004) DSR2 paper 

frequency_M2 = 2*omega_E - 2*n
% answer 1.4052e-04
% agrees with 1.405189e-4 value from Table 1 in Arbic et al. (2004) DSR2 paper 

frequency_S2 = 2*omega_E - 2*nprime
% answer 1.4544e-04
% agrees with 1.454441e-04 value from Table 1 in Arbic et al. (2004) DSR2 paper 

frequency_N2 = 2*omega_E -2*n - dl_dt
% answer 1.3788e-04
% agrees with 1.378797e-04 value from Table 1 in Arbic et al. (2004) DSR2 paper  

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Check that dOmega_dt is correct.  Convert it into a period measured in days:

nodalperiodindays = (2*pi/dOmega_dt)*(1/86400)
% answer -6810.1 
% Compare with value of 6798.4 days given on page 11 of Williams November 6, 2017 writeup

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Check that domegabar_dt is correct.  Convert it into a period measured in days:

longitudeofperigeeperiodindays = (2*pi/domegabar_dt)*(1/86400)
% answer 3237.7 
% compare with value of 3231.5 days given on page 11 of Williams November 6, 2017 writeup

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

frequency_diurnal_node = omega_E - dOmega_dt
% answer 7.2932e-05

frequency_diurnal_LplusF = omega_E - 2*n + dOmega_dt
% answer 6.7587e-05

frequency_semidiurnal_node = 2*omega_E - dOmega_dt
% answer 1.4585e-04

frequency_semidiurnal_LplusF = 2*omega_E - 2*n + dOmega_dt
% answer 1.4051e-04



period_diurnal_node = (1/86400)*2*pi/frequency_diurnal_node
% answer 0.9971 days
% Agrees with Table 4 of Williams and Boggs 2016

period_diurnal_LplusF = (1/86400)*2*pi/frequency_diurnal_LplusF
% answer 1.0760 days
% Agrees with Table 4 of Williams and Boggs 2016

period_semidiurnal_node = (1/86400)*2*pi/frequency_semidiurnal_node
% answer 0.4986 days
% Agrees with Table 5 of Williams and Boggs 2016

period_semidiurnal_LplusF = (1/86400)*2*pi/frequency_semidiurnal_LplusF
% answer 0.5176 days
% Agrees with Table 5 of Williams and Boggs 2016

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Two additional calculations, added 12 June 2021.  Compute nodal period and
%   period of change of perigee, in years:

nodalperiodindays / ( (2*pi/dlprime_dt)*(1/86400) )
% answer -18.6445

longitudeofperigeeperiodindays / ( (2*pi/dlprime_dt)*(1/86400) )
%  answer 8.8642
