% Re-run 13 June 2021, after the "v9" version of the parameter structure was 
%   generated

% Re-run 24 December 2020 after the "v8" version of the parameter structure
%  came out


% This code checks the ratios of the "U factors" for various constituents
% versus the ratios of tidal amplitudes from Table 1 of Arbic et al. 2004
% The "U factors" include the "1 + delta_q0" terms, as these are seen
% in both the d/dt formulae and the power dissipation formulae of
% Jim Williams

load parameters_presentday_v9_use_structures.mat

% Extract parameters needed to compute U factors and then to invert the dissipations to solve for ksinchi values:

inclination=PresentDayValues_orbitalparameters.inclination_presentday;
eccentricity=PresentDayValues_orbitalparameters.eccentricity_presentday;
epsilon=PresentDayValues_orbitalparameters.epsilon_presentday;
M_S=EarthMoon_constants.M_S;
a=PresentDayValues_orbitalparameters.a_presentday;
M_M=EarthMoon_constants.M_M;
aprime=EarthMoon_constants.aprime;
eccentricityprime=EarthMoon_constants.eccentricityprime;

G=EarthMoon_constants.G;
R=EarthMoon_constants.R;
n=PresentDayValues_orbitalparameters.n_presentday;

[U11minusU22plus2U12_K2_lunarpart,U11minusU22plus2U12_K2_solarpart,U11minusU22plus2U12_M2,U11minusU22plus2U12_S2,U11minusU22plus2U12_N2]=computeUcombinations_semidiurnaltides(inclination,eccentricity,epsilon,M_S,a,M_M,aprime,eccentricityprime);

[U13minusU23_K1_lunarpart,U13minusU23_K1_solarpart,U13minusU23_O1,U13minusU23_P1,U13minusU23_Q1]=computeUcombinations_diurnaltides(inclination,eccentricity,epsilon,M_S,a,M_M,aprime,eccentricityprime);

[U11plusU22minus2U33_constant_lunarpart,U11plusU22minus2U33_constant_solarpart,U11plusU22minus2U33_Mf,U11plusU22minus2U33_Mm]=computeUcombinations_longperiodtides(inclination,eccentricity,epsilon,M_S,a,M_M,aprime,eccentricityprime);


% Below we check ratios of the "U" factors, and compare them to ratios of the equilibrium tidal forcings from the Table 1 of the Arbic et al. 2004 paper

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Check ratios for semidiurnal tides:

oneplusdelta_q0_K2=ConstituentIndexParameters.vector_semidiurnal_oneplusdelta_q0(1);
oneplusdelta_q0_M2=ConstituentIndexParameters.vector_semidiurnal_oneplusdelta_q0(2);
oneplusdelta_q0_S2=ConstituentIndexParameters.vector_semidiurnal_oneplusdelta_q0(3);
oneplusdelta_q0_N2=ConstituentIndexParameters.vector_semidiurnal_oneplusdelta_q0(4);


% S2/M2
(oneplusdelta_q0_S2*U11minusU22plus2U12_S2)/(oneplusdelta_q0_M2*U11minusU22plus2U12_M2)
% answer 0.4634
% Compare to ratio from Arbic et al. 2004
11.2743/24.2334
% answer 0.4652

% N2/M2
(oneplusdelta_q0_N2*U11minusU22plus2U12_N2)/(oneplusdelta_q0_M2*U11minusU22plus2U12_M2)
% answer 0.1923
% Compare to ratio from Arbic et al. 2004
4.6397/24.2334
% answer 0.1915

% K2/M2
(oneplusdelta_q0_K2*(U11minusU22plus2U12_K2_lunarpart+U11minusU22plus2U12_K2_solarpart))/(oneplusdelta_q0_M2*U11minusU22plus2U12_M2)
% answer 0.1246
% Compare to ratio from Arbic et al. 2004
3.0684/24.2334
% answer 0.1266

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Check ratios for diurnal tides:

oneplusdelta_q0_K1=ConstituentIndexParameters.vector_diurnal_oneplusdelta_q0(1);
oneplusdelta_q0_O1=ConstituentIndexParameters.vector_diurnal_oneplusdelta_q0(2);
oneplusdelta_q0_P1=ConstituentIndexParameters.vector_diurnal_oneplusdelta_q0(3);
oneplusdelta_q0_Q1=ConstituentIndexParameters.vector_diurnal_oneplusdelta_q0(4);



% P1/O1
(oneplusdelta_q0_P1*U13minusU23_P1)/(oneplusdelta_q0_O1*U13minusU23_O1)
% answer 0.4634 
% Compare to ratio from Arbic et al. 2004
4.6848/10.0661
% answer 0.4654

% Q1/O1
(oneplusdelta_q0_Q1*U13minusU23_Q1)/(oneplusdelta_q0_O1*U13minusU23_O1)
% answer 0.1923
% Compare to ratio from Arbic et al. 2004
1.9273/10.0661
% answer 0.1915

% K1/O1
(oneplusdelta_q0_K1*(U13minusU23_K1_lunarpart+U13minusU23_K1_solarpart))/(oneplusdelta_q0_O1*U13minusU23_O1)
% answer -1.4070
% Compare to ratio from Arbic et al. 2004
14.1565/10.0661
% answer 1.4064

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Check ratios for long-period tides:

oneplusdelta_q0_Mf=ConstituentIndexParameters.vector_longperiod_oneplusdelta_q0(1);
oneplusdelta_q0_Mm=ConstituentIndexParameters.vector_longperiod_oneplusdelta_q0(2);

% Mm/Mf
(oneplusdelta_q0_Mm*U11plusU22minus2U33_Mm)/(oneplusdelta_q0_Mf*U11plusU22minus2U33_Mf)
% answer 0.5403
% Compare to ratio from Arbic et al. 2004
2.2191/4.2041
% answer 0.5278



