% Re-run 13 June 2021, after the "v9" version of the parameter structure was 
%   generated

% Re-run 24 December 2020 after the "v8" version of the parameter structure
%  came out

% This code checks the ratios of the "U factors" for various constituents
% versus the ratios of tidal amplitudes from Table 1 of Arbic et al. 2004
% The "U factors" include the "1 + delta_q0" terms, as these are seen
% in both the d/dt formulae and the power dissipation formulae of
% Jim Williams

load parameters_presentday_v9_use_structures_nodeLF.mat

% Extract parameters needed to compute U factors and then to invert the dissipations to solve for ksinchi values:

inclination=PresentDayValues_orbitalparameters.inclination_presentday;
eccentricity=PresentDayValues_orbitalparameters.eccentricity_presentday;
epsilon=PresentDayValues_orbitalparameters.epsilon_presentday;
M_S=EarthMoon_constants.M_S;
a=PresentDayValues_orbitalparameters.a_presentday;
M_M=EarthMoon_constants.M_M;
aprime=EarthMoon_constants.aprime;
eccentricityprime=EarthMoon_constants.eccentricityprime;

G=EarthMoon_constants.G;
R=EarthMoon_constants.R;
n=PresentDayValues_orbitalparameters.n_presentday;

[U11minusU22plus2U12_K2_lunarpart,U11minusU22plus2U12_K2_solarpart,U11minusU22plus2U12_M2,U11minusU22plus2U12_S2,U11minusU22plus2U12_N2,U11minusU22plus2U12_semidiurnal_node,U11minusU22plus2U12_semidiurnal_LF]=computeUcombinations_semidiurnaltides_nodeLF(inclination,eccentricity,epsilon,M_S,a,M_M,aprime,eccentricityprime);

[U13minusU23_K1_lunarpart,U13minusU23_K1_solarpart,U13minusU23_O1,U13minusU23_P1,U13minusU23_Q1,U13minusU23_diurnal_node,U13minusU23_diurnal_LF]=computeUcombinations_diurnaltides_nodeLF(inclination,eccentricity,epsilon,M_S,a,M_M,aprime,eccentricityprime);

[U11plusU22minus2U33_constant_lunarpart,U11plusU22minus2U33_constant_solarpart,U11plusU22minus2U33_Mf,U11plusU22minus2U33_Mm]=computeUcombinations_longperiodtides(inclination,eccentricity,epsilon,M_S,a,M_M,aprime,eccentricityprime);


% Below we check ratios of the "U" factors, and compare them to ratios of the equilibrium tidal forcings from the Table 1 of the Arbic et al. 2004 paper

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Check ratios for semidiurnal tides:

oneplusdelta_q0_K2=ConstituentIndexParameters.vector_semidiurnal_oneplusdelta_q0(1);
oneplusdelta_q0_M2=ConstituentIndexParameters.vector_semidiurnal_oneplusdelta_q0(2);
oneplusdelta_q0_S2=ConstituentIndexParameters.vector_semidiurnal_oneplusdelta_q0(3);
oneplusdelta_q0_N2=ConstituentIndexParameters.vector_semidiurnal_oneplusdelta_q0(4);
oneplusdelta_q0_semidiurnal_node=ConstituentIndexParameters.vector_semidiurnal_oneplusdelta_q0(5);
oneplusdelta_q0_semidiurnal_LF=ConstituentIndexParameters.vector_semidiurnal_oneplusdelta_q0(6);

% S2/M2
(oneplusdelta_q0_S2*U11minusU22plus2U12_S2)/(oneplusdelta_q0_M2*U11minusU22plus2U12_M2)
% answer 0.4634
% Compare to answer computed from Jims new table
( oneplusdelta_q0_S2*(0.42318+0.42166) ) / ( oneplusdelta_q0_M2*(0.91133+0.90806) )
% answer 0.4644
% Compare to ratio from Arbic et al. 2004
11.2743/24.2334
% answer 0.4652
% Compare to ratio from Table 6.7 of Petit and Luzum 2010 (IERS Conventions)
0.29400/0.63192
% answer 0.4652


% N2/M2
(oneplusdelta_q0_N2*U11minusU22plus2U12_N2)/(oneplusdelta_q0_M2*U11minusU22plus2U12_M2)
% answer 0.1923
% Compare to answer computed from Jims new table
( oneplusdelta_q0_N2*(0.17527+0.17464) ) / ( oneplusdelta_q0_N2*(0.91133+0.90806) )
% answer 0.1923
% Compare to ratio from Arbic et al. 2004
4.6397/24.2334
% answer 0.1915
% Compare to ratio fromTable 6.7 of Petit and Luzum 2010 (IERS Conventions)
0.12099/0.63192
% answer 0.1915


% K2/M2
(oneplusdelta_q0_K2*(U11minusU22plus2U12_K2_lunarpart+U11minusU22plus2U12_K2_solarpart))/(oneplusdelta_q0_M2*U11minusU22plus2U12_M2)
% answer 0.1246
% Compare to ratio from Arbic et al. 2004
3.0684/24.2334
% answer 0.1266

% Compare to answer computed from Jims new table
( oneplusdelta_q0_K2*(0.07745) ) / ( oneplusdelta_q0_N2*(0.91133+0.90806) )
% answer 0.0851
% Jims table must be for only the lunar part, because we can get nearly 
%    the same answer using only the lunar part:
(oneplusdelta_q0_K2*U11minusU22plus2U12_K2_lunarpart)/(oneplusdelta_q0_M2*U11minusU22plus2U12_M2)
% answer 0.0851 

% Compare to ratio fromTable 6.7 of Petit and Luzum 2010 (IERS Conventions)
0.07996/0.63192
% answer 0.1265



% Semidiurnal Node/M2
(oneplusdelta_q0_semidiurnal_node*U11minusU22plus2U12_semidiurnal_node)/(oneplusdelta_q0_M2*U11minusU22plus2U12_M2)
% answer 0.0374
% Compare to answer computed from Jims new table
( oneplusdelta_q0_semidiurnal_node*(0.03256+0.03545) ) / ( oneplusdelta_q0_M2*(0.91133+0.90806) )
% answer 0.0374
% Compare to ratio fromTable 6.7 of Petit and Luzum 2010 (IERS Conventions)
0.02383/0.63192
% answer 0.0377


% Semidiurnal L+F/M2
(oneplusdelta_q0_semidiurnal_LF*U11minusU22plus2U12_semidiurnal_LF)/(oneplusdelta_q0_M2*U11minusU22plus2U12_M2)
% answer -0.0370 
% Compare to answer computed from Jims new table
( oneplusdelta_q0_semidiurnal_LF*(-0.03224-0.03509) ) / ( oneplusdelta_q0_M2*(0.91133+0.90806) )
% answer -0.0370
% Compare to ratio fromTable 6.7 of Petit and Luzum 2010 (IERS Conventions)
0.02358/0.63192
% answer 0.0373




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Check ratios for diurnal tides:

oneplusdelta_q0_K1=ConstituentIndexParameters.vector_diurnal_oneplusdelta_q0(1);
oneplusdelta_q0_O1=ConstituentIndexParameters.vector_diurnal_oneplusdelta_q0(2);
oneplusdelta_q0_P1=ConstituentIndexParameters.vector_diurnal_oneplusdelta_q0(3);
oneplusdelta_q0_Q1=ConstituentIndexParameters.vector_diurnal_oneplusdelta_q0(4);
oneplusdelta_q0_diurnal_node=ConstituentIndexParameters.vector_diurnal_oneplusdelta_q0(5);
oneplusdelta_q0_diurnal_LF=ConstituentIndexParameters.vector_diurnal_oneplusdelta_q0(6);



% P1/O1
(oneplusdelta_q0_P1*U13minusU23_P1)/(oneplusdelta_q0_O1*U13minusU23_O1)
% answer 0.4634
% Compare to answer computed from Jims new table
( oneplusdelta_q0_P1*(0.09067+0.08329) ) / ( oneplusdelta_q0_O1*(0.19525+0.17937) )
% answer 0.4644
% Compare to ratio from Arbic et al. 2004
4.6848/10.0661
% answer 0.4654
% Compare to ratio fromTable 6.7 of Petit and Luzum 2010 (IERS Conventions)
0.12203/0.26221
% answer 0.4654



% Q1/O1
(oneplusdelta_q0_Q1*U13minusU23_Q1)/(oneplusdelta_q0_O1*U13minusU23_O1)
% answer 0.1923
% Compare to answer computed from Jims new table
( oneplusdelta_q0_Q1*(0.03755+0.0345) ) / ( oneplusdelta_q0_O1*(0.19525+0.17937) )
% answer 0.1923
% Compare to ratio from Arbic et al. 2004
1.9273/10.0661
% answer 0.1915
% Compare to ratio fromTable 6.7 of Petit and Luzum 2010 (IERS Conventions)
0.05020/0.26221
% answer 0.1914




% K1/O1
(oneplusdelta_q0_K1*(U13minusU23_K1_lunarpart+U13minusU23_K1_solarpart))/(oneplusdelta_q0_O1*U13minusU23_O1)
% answer -1.4070
% Compare to ratio from Arbic et al. 2004
14.1565/10.0661
% answer 1.4064

% Compare to answer computed from Jims new table
( oneplusdelta_q0_K1*(-0.18009) ) / ( oneplusdelta_q0_O1*(0.19525+0.17937) )
% answer -0.9615
% Jims table must be for only the lunar part, because we can get nearly 
%    the same answer using only the lunar part:
(oneplusdelta_q0_K1*U13minusU23_K1_lunarpart)/(oneplusdelta_q0_O1*U13minusU23_O1)
% answer -0.9614

% Compare to ratio fromTable 6.7 of Petit and Luzum 2010 (IERS Conventions)
0.36878/0.26221
% answer 1.4064

 

% Diurnal Node/O1
(oneplusdelta_q0_diurnal_node*U13minusU23_diurnal_node)/(oneplusdelta_q0_O1*U13minusU23_O1)
% answer -0.1924
% Compare to answer computed from Jims new table
( oneplusdelta_q0_diurnal_node*(-0.04121-0.03086) ) / ( oneplusdelta_q0_O1*(0.19525+0.17937) )
% answer -0.1924
% Compare to ratio fromTable 6.7 of Petit and Luzum 2010 (IERS Conventions)
0.05001/0.26221
% answer 0.1907



% Diurnal L+F/O1
(oneplusdelta_q0_diurnal_LF*U13minusU23_diurnal_LF)/(oneplusdelta_q0_O1*U13minusU23_O1)
% answer 0.1904
% Compare to answer computed from Jims new table
( oneplusdelta_q0_diurnal_LF*(0.04080+0.03055) ) / ( oneplusdelta_q0_O1*(0.19525+0.17937) )
% answer 0.1905
% Compare to ratio fromTable 6.7 of Petit and Luzum 2010 (IERS Conventions)
0.04946/0.26221
% answer 0.1886







%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Check ratios for long-period tides:

oneplusdelta_q0_Mf=ConstituentIndexParameters.vector_longperiod_oneplusdelta_q0(1);
oneplusdelta_q0_Mm=ConstituentIndexParameters.vector_longperiod_oneplusdelta_q0(2);

% Mm/Mf
(oneplusdelta_q0_Mm*U11plusU22minus2U33_Mm)/(oneplusdelta_q0_Mf*U11plusU22minus2U33_Mf)
% answer 0.5403
% Compare to answer computed from Jims new table
( oneplusdelta_q0_Mm*(0.15185-0.02681) ) / ( oneplusdelta_q0_Mf*(0.07714+0.15428) )
% answer 0.5403
% Compare to ratio from Arbic et al. 2004
2.2191/4.2041
% answer 0.5278
% Compare to ratio fromTable 6.7 of Petit and Luzum 2010 (IERS Conventions)
0.03518/0.06663
% answer 0.5280



