function [da_dt_tidesinMoon,da_dt_Moon_coremantledissipation] = compute_da_dt_tidesinMoon2(EarthMoon_constants,a,n,eccentricity,inclination,I_lunartilt,KoverC_Moon_coremantledissipation,xi_Moon_coremantledissipation);

% Altered on 12 June 2021; KoverC_Moon_coremantledissipation is no longer taken from EarthMoon_constants, but is a separate input because it changes over time

% Compute da_dt_tidesinMoon due to tides in Moon, from the first formula in Jim Williams writeup "Arbic More Moon Tides 112920.docx" in his email of November 29, 2020

% NOTE THAT FOR SIMPLICITY, THE ARGUMENTS OF THE Q VALUES RETAIN THE 
%   SUBSCRIPTS "M" THAT JIM USED IN HIS WORD DOCUMENT 
%   "Arbic More Moon Tides 112920" ; BUT IN THE PAPER WE USE THE
%   SUBSCRIPT "l" THAT LINES UP BETTER WITH TABLE 1 IN WILLIAMS AND BOGGS 2015

k2_tidesinMoon=EarthMoon_constants.k2_tidesinMoon;
Q_M=EarthMoon_constants.Q_M;
Q_F=EarthMoon_constants.Q_F;
Q_FplusM=EarthMoon_constants.Q_FplusM;
Q_2F=EarthMoon_constants.Q_2F;
Q_2FminusM=EarthMoon_constants.Q_2FminusM;
Q_2FplusM=EarthMoon_constants.Q_2FplusM;
Q_3F=EarthMoon_constants.Q_3F;
Q_3FminusM=EarthMoon_constants.Q_3FminusM;
Q_3FplusM=EarthMoon_constants.Q_3FplusM;

M_M=EarthMoon_constants.M_M;
M_E=EarthMoon_constants.M_E;
R_M=EarthMoon_constants.R_M;

%KoverC_Moon_coremantledissipation=EarthMoon_constants.KoverC_Moon_coremantledissipation;
CovermRsquared_Moon_coremantledissipation=EarthMoon_constants.CovermRsquared_Moon_coremantledissipation;

sinsquaredterm = (sin (inclination + I_lunartilt) )^2;

Q_M_term = (eccentricity^2) * ( 7 - (17/2)*sinsquaredterm ) * (1/Q_M) ;
Q_F_term = sinsquaredterm * ( 1 - (3/4)* sinsquaredterm - (eccentricity^2) ) * (1/Q_F) ; 
Q_FplusM_term = (1/2) * (eccentricity^2) * sinsquaredterm * ( 29 - (67/4)* sinsquaredterm ) * (1/Q_FplusM) ; 
Q_2F_term = (1/8) * (sinsquaredterm^2) * ( 5 - 9 * (eccentricity^2) ) * (1/Q_2F) ; 
Q_2FminusM_term = (1/8) * (sinsquaredterm^2) * ( (21/8) * (eccentricity^2) ) * (1/Q_2FminusM) ;
Q_2FplusM_term = (1/8) * (sinsquaredterm^2) * ( (495/8) * (eccentricity^2) ) * (1/Q_2FplusM) ;
Q_3F_term = (1/32) * (sinsquaredterm^3) * ( 3 * ( 1 - 5 *(eccentricity^2) ) ) * (1/Q_3F) ; 
Q_3FminusM_term = (1/32) * (sinsquaredterm^3) * ( (1/2) * (eccentricity^2) ) * (1/Q_3FminusM) ;
Q_3FplusM_term = (1/32) * (sinsquaredterm^3) * ( 49 * (eccentricity^2) ) * (1/Q_3FplusM) ;

da_dt_tidesinMoon = -3 * k2_tidesinMoon * (M_E/(M_E+M_M)) * (M_E/M_M) * ( (R_M/a)^5 ) * n * a * ( Q_M_term + Q_F_term + Q_FplusM_term + Q_2F_term + Q_2FminusM_term + Q_2FplusM_term + Q_3F_term + Q_3FminusM_term + Q_3FplusM_term );



% Compute da_dt_Moon_coremantledissipation due to core-mantle dissipation in Moon.  See Williams et al. 2001 and Williams emails of November 27, 2017

da_dt_Moon_coremantledissipation = - KoverC_Moon_coremantledissipation * ( 1 / ( 1 + xi_Moon_coremantledissipation^2 ) ) * CovermRsquared_Moon_coremantledissipation * ( 1 + ( M_M/M_E ) ) * ( ( R_M/a )^2 ) * 2 * a * ( ( sin (I_lunartilt) )^2 ) ;



