function [deccentricity_dt_tidesinMoon] = compute_deccentricity_dt_tidesinMoon2(EarthMoon_constants,a,n,eccentricity,inclination,I_lunartilt);

% Compute deccentricity_dt_tidesinMoon due to tides in Moon, from the first formula in Jim Williams writeup "Arbic More Moon Tides 112920.docx" in his email of November 29, 2020

% Note that the output variable includes the extension "_tidesinMoon", 
% to make it consistent with outputs from the "tidesinMoon2" computations 
% for d/dt of inclination and a

% NOTE THAT FOR SIMPLICITY, THE ARGUMENTS OF THE Q VALUES RETAIN THE 
%   SUBSCRIPTS "M" THAT JIM USED IN HIS WORD DOCUMENT 
%   "Arbic More Moon Tides 112920" ; BUT IN THE PAPER WE USE THE
%   SUBSCRIPT "l" THAT LINES UP BETTER WITH TABLE 1 IN WILLIAMS AND BOGGS 2015

k2_tidesinMoon=EarthMoon_constants.k2_tidesinMoon;
Q_M=EarthMoon_constants.Q_M;
Q_F=EarthMoon_constants.Q_F;
Q_FminusM=EarthMoon_constants.Q_FminusM;
Q_FplusM=EarthMoon_constants.Q_FplusM;
Q_2F=EarthMoon_constants.Q_2F;
Q_2FminusM=EarthMoon_constants.Q_2FminusM;
Q_2FplusM=EarthMoon_constants.Q_2FplusM;
Q_3F=EarthMoon_constants.Q_3F;
Q_3FminusM=EarthMoon_constants.Q_3FminusM;
Q_3FplusM=EarthMoon_constants.Q_3FplusM;
Q_4F=EarthMoon_constants.Q_4F;
Q_4FminusM=EarthMoon_constants.Q_4FminusM;
Q_4FplusM=EarthMoon_constants.Q_4FplusM;

M_M=EarthMoon_constants.M_M;
M_E=EarthMoon_constants.M_E;
R_M=EarthMoon_constants.R_M;

sinsquaredterm = (sin (inclination + I_lunartilt) )^2;

Q_M_term = ( 1 - (eccentricity)^2 ) * ( 14 -17 * sinsquaredterm ) * (1/Q_M);
Q_F_term = -(1/2) * sinsquaredterm * ( 2 - (3/2) * sinsquaredterm -2 * (eccentricity^2) ) * (1/Q_F);
Q_FminusM_term = -(1/4) * sinsquaredterm * ( 10 - (19/2) * sinsquaredterm ) * (1/Q_FminusM);
Q_FplusM_term = (1/4) * sinsquaredterm * ( 58 - (67/2) * sinsquaredterm ) * (1/Q_FplusM);
Q_2F_term = -(5/8) * (sinsquaredterm^2) * (1/Q_2F);
Q_2FminusM_term = (3/32) * eccentricity * (sinsquaredterm^2) * (-7) * (1/Q_2FminusM); 
Q_2FplusM_term = (3/32) * eccentricity * (sinsquaredterm^2) * (55) * (1/Q_2FplusM);  
Q_3F_term = (1/128) * (sinsquaredterm^3) * (-3/2) * (1/Q_3F);
Q_3FminusM_term = (1/128) * (sinsquaredterm^3) * (-1/4) * (1/Q_3FminusM);
Q_3FplusM_term = (1/128) * (sinsquaredterm^3) * (49/4) * (1/Q_3FplusM);
Q_4F_term = (1/256) * (sinsquaredterm^2) * (-1) * (1/Q_4F);
Q_4FminusM_term = (1/256) * (sinsquaredterm^2) * (-1/8) * (1/Q_4FminusM);
Q_4FplusM_term = (1/256) * (sinsquaredterm^2) * (49/8) * (1/Q_4FplusM);



deccentricity_dt_tidesinMoon = -(3/4) * k2_tidesinMoon * (M_E/(M_E+M_M)) * (M_E/M_M) * ( (R_M/a)^5 ) * n * eccentricity * (Q_M_term + Q_F_term + Q_FminusM_term + Q_FplusM_term + Q_2F_term + Q_2FminusM_term + Q_2FplusM_term + Q_3F_term + Q_3FminusM_term + Q_3FplusM_term + Q_4F_term + Q_4FminusM_term + Q_4FplusM_term ); 
