function [KoverC_Moon_coremantledissipation,xi_Moon_coremantledissipation,I_lunartilt] = compute_lunarequatorialtilt_Williams2001(dOmega_dt,a,inclination,n,EarthMoon_constants);

% Rewritten 21 June 2021 to accommodate variable (non-constant) KoverC_Moon_coremantledissipation, in response to reviewer Mathieu Dumberry comments on first submission.

% Computes lunar equatorial tilt from equation (52c) of Williams et al. (2001)

% Save variables needed by root2d_for_Williams2001_variableKoverC.m:
save temp.mat dOmega_dt a inclination n EarthMoon_constants

fun=@root2d_for_Williams2001_variableKoverC;
x0=[0,0,0];
x=fsolve(fun,x0);

KoverC_Moon_coremantledissipation=x(1);
xi_Moon_coremantledissipation=x(2);
I_lunartilt=x(3);

%if abs( imag(KoverC_Moon_coremantledissipation) / real(KoverC_Moon_coremantledi%ssipation) ) > 0.1 | abs( imag(xi_Moon_coremantledissipation) / real(xi_Moon_co%remantledissipation) ) > 0.1 | abs( imag(I_lunartilt) / real(I_lunartilt) ) > 0%.1
%  KoverC_Moon_coremantledissipation=nan;
%  xi_Moon_coremantledissipation=nan;
%  I_lunartilt=nan;
%end

% Note that if we use the criterion above (0.1 instead of 0.01) we end up 
% with only a few more good answers, and some of these do not make sense in 
% other ways--I takes on values greater than 90 degrees, for instance--so we 
% end up using 0.01 as a criterion below, and we also add the criterion that
% the absolute value of I should be less than 90 degrees: 

  if abs( imag(KoverC_Moon_coremantledissipation) / real(KoverC_Moon_coremantledissipation) ) > 0.01 | abs( imag(xi_Moon_coremantledissipation) / real(xi_Moon_coremantledissipation) ) > 0.01 | abs( imag(I_lunartilt) / real(I_lunartilt) ) > 0.01 | abs( (180/pi)*real(I_lunartilt) > 90)
  KoverC_Moon_coremantledissipation=nan;
  xi_Moon_coremantledissipation=nan;
  I_lunartilt=nan;
end

% Now get rid of the imaginary values, which could cause problems in 
%  an integration of the orbital dynamics equations:

KoverC_Moon_coremantledissipation=real(KoverC_Moon_coremantledissipation);
xi_Moon_coremantledissipation=real(xi_Moon_coremantledissipation);
I_lunartilt=real(I_lunartilt);



