function F = root2d_for_Williams2001_variableKoverC(x);

% Subroutine needed to compute KoverC, xi, and I_lunartilt parameters from Williams et al. 2001 equations--must be solved for simultaneously because KoverC is a function of xi and I, I is a function of KoverC and xi, etc.--these are all needed for computing impacts of core-mantle dissipation in Moon

% load variables saved in compute_lunarequatorialtilt_Williams2001.m:
load temp.mat 

% Write out x vector variables as KoverC, xi, and I--these are closer to the names of the actual variables in the equations below, which come from older codes, so it feels more intuitive to use these names:

KoverC=x(1);
xi=x(2);
I=x(3);

beta_tidesinMoon=EarthMoon_constants.beta_tidesinMoon;
gamma_tidesinMoon=EarthMoon_constants.gamma_tidesinMoon;
alpha_tidesinMoon=EarthMoon_constants.alpha_tidesinMoon;
CoverCprime_Moon_coremantledissipation=EarthMoon_constants.CoverCprime_Moon_coremantledissipation;
CovermRsquared_Moon_coremantledissipation=EarthMoon_constants.CovermRsquared_Moon_coremantledissipation;
k2_tidesinMoon=EarthMoon_constants.k2_tidesinMoon;
M_E=EarthMoon_constants.M_E;
M_M=EarthMoon_constants.M_M;
R_M=EarthMoon_constants.R_M;

Fdot=n-dOmega_dt;

zeta_tidesinMoon=(1/CovermRsquared_Moon_coremantledissipation)*(M_E/M_M)*( (R_M/a)^3 );
E=(k2_tidesinMoon*zeta_tidesinMoon)/3;

G_b_partial=(3*n^2)*(0.9754*beta_tidesinMoon+0.0048*alpha_tidesinMoon+E)-1.9982*(dOmega_dt^2)-2*Fdot*KoverC*(xi/(1+xi^2));

G_t_partial=-3*(n^2)*sin(inclination)*(0.9865*beta_tidesinMoon+0.0041*alpha_tidesinMoon+E);

% Write equation for KoverC:

F(1) = KoverC - (45/32)*pi*(1/CoverCprime_Moon_coremantledissipation)*( (0.4^2) / ( ( 14.631 - log(1 + ( xi )^2) )^2 ) ) * (Fdot*abs(sin(I))) * (1 / ( (1 + ( xi)^2)^(1/2) ) ); 

% Write equation for xi_Moon_coremantle_dissipation:

F(2) = xi + KoverC * CoverCprime_Moon_coremantledissipation * ( 1 / dOmega_dt );

% Write equation for I:

F(3) = sin(I) - G_t_partial * ( sqrt( 1 - ( ( 2*KoverC*Fdot*sin(I)*cos(I) ) / ( 3* (1+xi^2)*(n^2)*sin(inclination)*(0.9840*beta_tidesinMoon+0.0059*alpha_tidesinMoon) )  )^2 ) ) / ( G_b_partial + (2.0002*dOmega_dt*( dOmega_dt*cos(I)+Fdot ) ) ) ;

