% On June 12, 2021, we took out the pre-set value of K_moon/C_moon, which
%    will now be solved for within the equations.


% On January 12, 2021, we added udpated k2Moon, lunar Q, CoverCprime, 
%    and KoverC values based on communications with Jim Williams 



% On December 23, 2020, we added the updated k2Moon and lunar Q values based on communications with Jim Williams

% On August 23, 2020, we added the CminusAoverC_tidesinMoon parameter because we realised that the Ward 1975 equation for sin I actually uses CminusAoverC rather than beta--they are so close together that it should not make much practical difference

% On August 13, 2020, we added the gamma_tidesinMoon, alpha_tidesinMoon, k2_tidesinMoon, and S3 parameters, in order to use the Williams et al. 2001 equation (52c) to solve for lunar equatorial tilt I

% On June 5, 2020, we replaced the misleading name "zetafactor"
%    with the more accurate name "qfactor"

% This code was created on June 1, 2020, to add in values for the 
%  four diurnal and semidiurnal node and L+F constituents


% This code was changed on March 4, 2020, to put everything into
%  structures without having to use the "initialize..." functions,
%  which had an unwieldy number of inputs


% This code was changed on August 25, 2019, to put everything into
%  a relatively small number of structures


% This code was changed again on June 17, 2019, to add new constants
%    introduced in emails from Jim Williams:  "c" (constant in 
%    updated code for computing lunar equatorial tilt) 
    

% This code was changed on March 26, 2019, building upon the code
%    set_parameters_presentday_eccentricityprime_equals_RMSvalue.m;
%    differences between the "eccentricityprime..." code and the 
%    original code are described below.  The differences in this 
%    "v3" code are prompted by the March 25,  2019 email from Jim
%    Williams,  suggesting a change in present-day eccentricityprime  
%    and obliquity values


% THIS CODE IS THE SAME AS set_parameters_presentday.m, except that 
%    eccentricityprime is set to be the RMS value instead of the 
%    present-day value
% The variable name is still "eccentricityprime" just so the codes
%    that call upon it do not have to be changed

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Create a structure of Earth-Moon constants.
% Values follow Jim Williams writeups of 17 October and 16 November 2017, except that units are MKS

% Set the parameters needed for the corrections due to the tides in the Moon:

beta_tidesinMoon=631*10^-6;
EarthMoon_constants(1).beta_tidesinMoon=631*10^-6;
gamma_tidesinMoon=2.28*10^-4; % See page 1078 of Williams et al. 1996
EarthMoon_constants(1).gamma_tidesinMoon=2.28*10^-4; 
EarthMoon_constants(1).alpha_tidesinMoon=(beta_tidesinMoon-gamma_tidesinMoon)/(1-beta_tidesinMoon*gamma_tidesinMoon)  % See page 27936 of Williams et al. 2001
EarthMoon_constants(1).S3=0.9759; % See page 27945 of Williams et al. 2001
%EarthMoon_constants(1).k2_tidesinMoon=0.03; % see page 27935 of Williams et al. 2001

EarthMoon_constants(1).CminusAoverC_tidesinMoon=beta_tidesinMoon*(1+gamma_tidesinMoon)/(1+beta_tidesinMoon);

%EarthMoon_constants(1).k2_over_Q_tidesinMoon=5.323621E-04; % More exact value given in 16 November 2017 writeup

EarthMoon_constants(1).k2_over_Q_tidesinMoon=8.1E-04; % Value given in comments on paper draft from Jim Williams in January 2021; see his comments on Table 9 in "TidesPaper_Daheretal 123120 JGW.pdf"

EarthMoon_constants(1).k2_tidesinMoon=0.02416; % More exact value taken from Williams and Boggs 2015 after conversations in late 2020 with Jim Williams
% Similarly, values of various Q factors are taken from table sent in late 2020 by Jim Williams
EarthMoon_constants(1).Q_M=42/1.312;
EarthMoon_constants(1).Q_F=42/1.312;
EarthMoon_constants(1).Q_FminusM=170/1.312;
EarthMoon_constants(1).Q_FplusM=50/1.312;
EarthMoon_constants(1).Q_2F=50/1.312;
EarthMoon_constants(1).Q_2FminusM=42/1.312;
EarthMoon_constants(1).Q_2FplusM=54/1.312;
EarthMoon_constants(1).Q_3F=54/1.312;
EarthMoon_constants(1).Q_3FminusM=50/1.312;
EarthMoon_constants(1).Q_3FplusM=56/1.312;
EarthMoon_constants(1).Q_4F=56/1.312;
EarthMoon_constants(1).Q_4FminusM=54/1.312;
EarthMoon_constants(1).Q_4FplusM=57/1.312;

%EarthMoon_constants(1).KoverC_Moon_coremantledissipation=1.636562*(10^-8)*(1/86400); % value given in November 27, 2017 email from Jim Williams
%EarthMoon_constants(1).KoverC_Moon_coremantledissipation=0.9*(10^-8)*(1/86400); % value given in comments on paper draft from Jim Williams in January 2021; see his comments on Table 9 in "TidesPaper_Daheretal 123120 JGW.pdf"
%EarthMoon_constants(1).CoverCprime_Moon_coremantledissipation=1/0.0007; % value given in November 27, 2017 email from Jim Williams
EarthMoon_constants(1).CoverCprime_Moon_coremantledissipation=1/0.0004; % value given in January 12, 2021 email from Jim Williams
EarthMoon_constants(1).CovermRsquared_Moon_coremantledissipation=0.3929; % value from Williams et al. (2014) paper combining GRAIL and LLR data

EarthMoon_constants(1).C_0=0.3299;  % value of C_0/M_E R^2, see Williams writeup of 6 November 2017
EarthMoon_constants(1).G=6.67384*10^(-11); % Newton gravitational constant in m^3/(kg s^2)
EarthMoon_constants(1).M_M=7.34630*10^22; % Mass of Moon in kg

M_EoverM_M=81.300569; % ratio of Earth to Moon masses

EarthMoon_constants(1).M_E=EarthMoon_constants.M_M*M_EoverM_M; % set Earth mass (in kg) based upon previous two values which come from Jims "JPL approved" list

% Check that M_E so defined is close to Wikipedia value 
EarthMoon_constants.M_E
%   answer 5.9726*10^24 kg; Wikipedia value is 5.9722*10^24 kg

M_SoverM_E=332946.0488; % ratio of solar to Earth masses

EarthMoon_constants(1).M_S=EarthMoon_constants.M_E*M_SoverM_E; % set solar mass (in kg) based upon "JPL approved" values

% Check that M_S so defined is close to Wikipedia value
EarthMoon_constants.M_S
%   answer 1.9885*10^30 kg; Wikipedia value is 1.98855*10^30 kg

EarthMoon_constants(1).R=6378.136*10^3; % Earth equatorial radius in meters
EarthMoon_constants(1).R_M=1738.0*10^3; % Moon reference radius in meters
EarthMoon_constants(1).Roche=9.492*10^6; % Roche limit in meters for Earth-Moon system according to Wikipedia ; CHECK THIS WITH CO-AUTHORS
EarthMoon_constants(1).aprime=149598023*1000; % heliocentric major axis (Earth-Sun distance) in meters
EarthMoon_constants(1).eccentricityprime=0.0316227766; % square root of 0.001; RMS (over time) eccentricity of Earth orbit around sun; see March 25, 2019 email from Jim Williams, following up on "Comments Orbital Evolution Equations" from Jim Williams (sent in an email March 15, 2019)
EarthMoon_constants(1).h2fluid=1.93; % fluid h Love number
EarthMoon_constants(1).k2fluid=0.93; % fluid k Love number

nprime_presentday_arcsecondsperyear=1295977.4; % annual mean motion nprime in arcseconds/year

EarthMoon_constants(1).nprime=nprime_presentday_arcsecondsperyear*(1/60)*(1/60)*(2*pi/360)*(1/365.25)*(1/86400); % annual mean motion nprime in radians per second

% Check that nprime_presentday is as expected
EarthMoon_constants.nprime
% answer 1.9910*10^-7
(2*pi/(365.25*86400))
% answer 1.9910*10^-7; good

EarthMoon_constants(1).sfluid=0.09;  % Love-number-like parameter for spherical distortion; see Williams writeup of 6 November 2017

% New parameter introduced by Jim Williams in June 2019 email:

EarthMoon_constants(1).c=0.006;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Create structure for storing present-day values of a, eccentricity, etc.:

PresentDayValues_orbitalparameters(1).a_presentday=384399.0*1000; % lunar a, in meters
PresentDayValues_orbitalparameters(1).eccentricity_presentday=0.0549; % present-day eccentricity of lunar orbit
PresentDayValues_orbitalparameters(1).inclination_presentday=5.145*pi/180; % present-day lunar inclination, in radians

n_presentday_arcsecondsperyear=17325593.4; % present-day lunar mean motion n in arcseconds/year 

PresentDayValues_orbitalparameters(1).n_presentday=n_presentday_arcsecondsperyear*(1/60)*(1/60)*(2*pi/360)*(1/365.25)*(1/86400); % present-day lunar mean motion n in radians per second

% Check that n_presentday is as expected
PresentDayValues_orbitalparameters.n_presentday
% answer 2.6617*10^-6
(2*pi/(2*13.661*86400))
% answer 2.6617*10^-6; good

PresentDayValues_orbitalparameters(1).omega_E_presentday=7.292116*10^-5; % Earth rotation rate, in radians per second
PresentDayValues_orbitalparameters(1).epsilon_presentday=23.2708*pi/180; % Earth obliquity, in radians, with Milankovich cycle variations removed
PresentDayValues_orbitalparameters(1).S_W_presentday=1.005; % allows for the small dependence of the moment of inertia on spin rate 
PresentDayValues_orbitalparameters(1).S_A_presentday=1 + (2*EarthMoon_constants.nprime^2)/PresentDayValues_orbitalparameters.n_presentday^2; % 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Create structures for the present-day body and ocean tide ksinchi values:

%  In integrations that use results from Schindeleggers ocean tide simulations, some of 
%  these will be changed at every time step throughout the integration.
%  Note we are currently assuming that the long-period ocean tide ksinchi 
%  values,  and the body tide ksinchi values for all constituents, hold
%  throughout the simulation.  

% Set the "ksinchi" values for the present-day body tides:

ksinchi_M2_bodytide_presentday=0.0013;
ksinchi_S2_bodytide_presentday=0.0013;
ksinchi_N2_bodytide_presentday=0.0013;
ksinchi_K2_bodytide_presentday=0.0013;
kinschi_semidiurnal_node_bodytide_presentday=0.0013;
ksinchi_semidiurnal_LF_bodytide_presentday=0.0013;

ksinchi_K1_bodytide_presentday=-0.0012;
ksinchi_O1_bodytide_presentday=0.0014;
ksinchi_P1_bodytide_presentday=0.0007;
ksinchi_Q1_bodytide_presentday=0.0014;
kinschi_diurnal_node_bodytide_presentday=-0.0015;
ksinchi_diurnal_LF_bodytide_presentday=0.0014;

ksinchi_Mf_bodytide_presentday=0.0021;
ksinchi_Mm_bodytide_presentday=0.0024;

% Set the "ksinchi" values for the present-day ocean tides:

ksinchi_M2_oceantide_presentday=0.0237;
ksinchi_S2_oceantide_presentday=0.0171;
ksinchi_N2_oceantide_presentday=0.0308;
ksinchi_K2_oceantide_presentday=0.0175;
kinschi_semidiurnal_node_oceantide_presentday=0.0175;
ksinchi_semidiurnal_LF_oceantide_presentday=0.0237;

ksinchi_K1_oceantide_presentday=0.0162;
ksinchi_O1_oceantide_presentday=0.0220;
ksinchi_P1_oceantide_presentday=0.0161;
ksinchi_Q1_oceantide_presentday=0.0226;
kinschi_diurnal_node_oceantide_presentday=0.0162;
ksinchi_diurnal_LF_oceantide_presentday=0.0220;

ksinchi_Mf_oceantide_presentday=0.0098;
ksinchi_Mm_oceantide_presentday=0.0066;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% This block of code replaces the call to 
%   "initialize_vectors_ksinchi_usepresentdaydissipation", 
%   which had an unwieldy number of inputs.

% This code creates vectors of the ksinchi values for integrations that use present-day ksinchi values:

% Create vector of long-period body tide ksinchi values, omitting the "CONSTANT" term:

vector_longperiod_ksinchi_bodytide=[ksinchi_Mf_bodytide_presentday ksinchi_Mm_bodytide_presentday];

% Create vector of long-period ocean tide ksinchi values, omitting the "CONSTANT" term:

vector_longperiod_ksinchi_oceantide=[ksinchi_Mf_oceantide_presentday ksinchi_Mm_oceantide_presentday];


% Create vector of diurnal body tide ksinchi values:

vector_diurnal_ksinchi_bodytide=[ksinchi_K1_bodytide_presentday ksinchi_O1_bodytide_presentday ksinchi_P1_bodytide_presentday ksinchi_Q1_bodytide_presentday kinschi_diurnal_node_bodytide_presentday ksinchi_diurnal_LF_bodytide_presentday];

% Create vector of diurnal ocean tide ksinchi values:

vector_diurnal_ksinchi_oceantide=[ksinchi_K1_oceantide_presentday ksinchi_O1_oceantide_presentday ksinchi_P1_oceantide_presentday ksinchi_Q1_oceantide_presentday kinschi_diurnal_node_oceantide_presentday ksinchi_diurnal_LF_oceantide_presentday];

% Create vector of semidiurnal body tide ksinchi values:

vector_semidiurnal_ksinchi_bodytide=[ksinchi_K2_bodytide_presentday ksinchi_M2_bodytide_presentday ksinchi_S2_bodytide_presentday ksinchi_N2_bodytide_presentday kinschi_semidiurnal_node_bodytide_presentday ksinchi_semidiurnal_LF_bodytide_presentday];

% Create vector of semidiurnal ocean tide ksinchi values:

vector_semidiurnal_ksinchi_oceantide=[ksinchi_K2_oceantide_presentday ksinchi_M2_oceantide_presentday ksinchi_S2_oceantide_presentday ksinchi_N2_oceantide_presentday kinschi_semidiurnal_node_oceantide_presentday ksinchi_semidiurnal_LF_oceantide_presentday];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Create vectors of ksinchi values for simulations with constant, present-day values of ksinchi

vector_diurnal_ksinchi_oceantide_constantpresentdayvalues=vector_diurnal_ksinchi_oceantide;
vector_semidiurnal_ksinchi_oceantide_constantpresentdayvalues=vector_semidiurnal_ksinchi_oceantide;

% For the simulations that use the ocean tide results from the Schindelegger model, we
% zero out the vectors for the diurnal and semidiurnal ocean tide 
% ksinchi values, which will be over-written in the timestepping code
%  below:

%vector_diurnal_ksinchi_oceantide=0*vector_diurnal_ksinchi_oceantide;
%vector_semidiurnal_ksinchi_oceantide=0*vector_semidiurnal_ksinchi_oceantide;

% Generate structure of kinschi values:

ksinchi_vectors(1).vector_longperiod_ksinchi_bodytide=vector_longperiod_ksinchi_bodytide;
clear vector_longperiod_ksinchi_bodytide
ksinchi_vectors(1).vector_longperiod_ksinchi_oceantide=vector_longperiod_ksinchi_oceantide;
clear vector_longperiod_ksinchi_oceantide
ksinchi_vectors(1).vector_diurnal_ksinchi_bodytide=vector_diurnal_ksinchi_bodytide;
clear vector_diurnal_ksinchi_bodytide
ksinchi_vectors(1).vector_diurnal_ksinchi_oceantide=vector_diurnal_ksinchi_oceantide;
clear vector_diurnal_ksinchi_oceantide
ksinchi_vectors(1).vector_semidiurnal_ksinchi_bodytide=vector_semidiurnal_ksinchi_bodytide;
clear vector_semidiurnal_ksinchi_bodytide
ksinchi_vectors(1).vector_semidiurnal_ksinchi_oceantide=vector_semidiurnal_ksinchi_oceantide;
clear vector_semidiurnal_ksinchi_oceantide
ksinchi_vectors(1).vector_diurnal_ksinchi_oceantide_constantpresentdayvalues=vector_diurnal_ksinchi_oceantide_constantpresentdayvalues;
clear vector_diurnal_ksinchi_oceantide_constantpresentdayvalues
ksinchi_vectors(1).vector_semidiurnal_ksinchi_oceantide_constantpresentdayvalues=vector_semidiurnal_ksinchi_oceantide_constantpresentdayvalues;

clear ksinchi_Mf_bodytide_presentday ksinchi_Mm_bodytide_presentday ksinchi_Mf_oceantide_presentday ksinchi_Mm_oceantide_presentday ksinchi_K1_bodytide_presentday ksinchi_O1_bodytide_presentday ksinchi_P1_bodytide_presentday ksinchi_Q1_bodytide_presentday ksinchi_K1_oceantide_presentday ksinchi_O1_oceantide_presentday ksinchi_P1_oceantide_presentday ksinchi_Q1_oceantide_presentday ksinchi_K2_bodytide_presentday ksinchi_M2_bodytide_presentday ksinchi_S2_bodytide_presentday ksinchi_N2_bodytide_presentday ksinchi_K2_oceantide_presentday ksinchi_M2_oceantide_presentday ksinchi_S2_oceantide_presentday ksinchi_N2_oceantide_presentday   
clear vector_semidiurnal_ksinchi_oceantide_constantpresentdayvalues vector_diurnal_ksinchi_oceantide_constantpresentdayvalues
clear ksinchi_semidiurnal_node_bodytide_presentday 
clear ksinchi_semidiurnal_LF_bodytide_presentday
clear ksinchi_diurnal_node_bodytide_presentday 
clear ksinchi_diurnal_LF_bodytide_presentday
clear ksinchi_semidiurnal_node_oceantide_presentday 
clear ksinchi_semidiurnal_LF_oceantide_presentday
clear ksinchi_diurnal_node_oceantide_presentday 
clear ksinchi_diurnal_LF_oceantide_presentday

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Create a structure of constituent index parameters:

% Set the j values from the Table on page 9 of Williams October 17 writeup

jM_M2=2;
jM_S2=0;
jM_N2=3;
jM_K2=0;
jM_semidiurnal_node=0;
jM_semidiurnal_LF=2;

jM_K1=0;
jM_O1=2;
jM_P1=0;
jM_Q1=3;
jM_diurnal_node=0;
jM_diurnal_LF=2;

jM_Mf=2;
jM_Mm=1;




jW_M2=2;
jW_S2=0;
jW_N2=2;
jW_K2=0;
jW_semidiurnal_node=0;
jW_semidiurnal_LF=2;

jW_K1=0;
jW_O1=2;
jW_P1=0;
jW_Q1=2;
jW_diurnal_node=0;
jW_diurnal_LF=2;

jW_Mf=2;
jW_Mm=0;




jOmega_M2=2;
jOmega_S2=0;
jOmega_N2=2;
jOmega_K2=0;
jOmega_semidiurnal_node=1;
jOmega_semidiurnal_LF=1;

jOmega_K1=0;
jOmega_O1=2;
jOmega_P1=0;
jOmega_Q1=2;
jOmega_diurnal_node=1;
jOmega_diurnal_LF=1;

jOmega_Mf=2;
jOmega_Mm=0;

% Set the "1+delta_q0" values:

oneplusdelta_q0_M2=1;
oneplusdelta_q0_S2=1;
oneplusdelta_q0_N2=1;
oneplusdelta_q0_K2=2;
oneplusdelta_q0_semidiurnal_node=1;
oneplusdelta_q0_semidiurnal_LF=1;

oneplusdelta_q0_K1=2;
oneplusdelta_q0_O1=1;
oneplusdelta_q0_P1=1;
oneplusdelta_q0_Q1=1;
oneplusdelta_q0_diurnal_node=1;
oneplusdelta_q0_diurnal_LF=1;

oneplusdelta_q0_longperiodconstant=2;
oneplusdelta_q0_Mf=1;
oneplusdelta_q0_Mm=1;

% Set the "qfactor" values (see Jim Williams email of 16 November 2017; these matter for the K1 and K2 domega_E_dt and depsilon_dt values):

qfactor_M2=1;
qfactor_S2=1;
qfactor_N2=1;
qfactor_K2=2;
qfactor_semidiurnal_node=1;
qfactor_semidiurnal_LF=1;

qfactor_K1=2;
qfactor_O1=1;
qfactor_P1=1;
qfactor_Q1=1;
qfactor_diurnal_node=1;
qfactor_diurnal_LF=1;

qfactor_longperiodconstant=2;
qfactor_Mf=1;
qfactor_Mm=1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% This block of code replaces the call to "initialize_vectors_delta_q0_qfactor_jvalues", which had an unwieldy number of inputs.

% This code creates vectors of many of the fixed quantities, such as oneplusdelta_q0, qfactor, jM, jW, and jOmega, that are used in the main time-stepping routine:


% Create vectors of long-period oneplusdelta_q0 values, "qfactor" values,jM values, jW values, and jOmega values, omitting the "CONSTANT" term:

vector_longperiod_oneplusdelta_q0=[oneplusdelta_q0_Mf oneplusdelta_q0_Mm];

vector_longperiod_qfactor=[qfactor_Mf];

vector_longperiod_jM=[jM_Mf jM_Mm];

vector_longperiod_jW=[jW_Mf jW_Mm];

vector_longperiod_jOmega=[jOmega_Mf jOmega_Mm];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Create vectors of diurnal oneplusdelta_q0 values, "qfactor" values, jM values, jW values, and jOmega values:

vector_diurnal_oneplusdelta_q0=[oneplusdelta_q0_K1 oneplusdelta_q0_O1 oneplusdelta_q0_P1 oneplusdelta_q0_Q1 oneplusdelta_q0_diurnal_node oneplusdelta_q0_diurnal_LF];

vector_diurnal_qfactor=[qfactor_K1 qfactor_O1 qfactor_P1 qfactor_Q1 qfactor_diurnal_node qfactor_diurnal_LF];

vector_diurnal_jM=[jM_K1 jM_O1 jM_P1 jM_Q1 jM_diurnal_node jM_diurnal_LF];

vector_diurnal_jW=[jW_K1 jW_O1 jW_P1 jW_Q1 jW_diurnal_node jW_diurnal_LF];

vector_diurnal_jOmega=[jOmega_K1 jOmega_O1 jOmega_P1 jOmega_Q1 jOmega_diurnal_node jOmega_diurnal_LF];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Create vectors of semidiurnal oneplusdelta_q0 values, "qfactor" values, jM values, jW values, and jOmega values:

vector_semidiurnal_oneplusdelta_q0=[oneplusdelta_q0_K2 oneplusdelta_q0_M2 oneplusdelta_q0_S2 oneplusdelta_q0_N2 oneplusdelta_q0_semidiurnal_node oneplusdelta_q0_semidiurnal_LF];

vector_semidiurnal_qfactor=[qfactor_K2 qfactor_M2 qfactor_S2 qfactor_N2 qfactor_semidiurnal_node qfactor_semidiurnal_LF];

vector_semidiurnal_jM=[jM_K2 jM_M2 jM_S2 jM_N2 jM_semidiurnal_node jM_semidiurnal_LF];

vector_semidiurnal_jW=[jW_K2 jW_M2 jW_S2 jW_N2 jW_semidiurnal_node jW_semidiurnal_LF];

vector_semidiurnal_jOmega=[jOmega_K2 jOmega_M2 jOmega_S2 jOmega_N2 jOmega_semidiurnal_node jOmega_semidiurnal_LF];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ConstituentIndexParameters(1).vector_longperiod_oneplusdelta_q0=vector_longperiod_oneplusdelta_q0;
clear vector_longperiod_oneplusdelta_q0
ConstituentIndexParameters(1).vector_longperiod_qfactor=vector_longperiod_qfactor;
clear vector_longperiod_qfactor
ConstituentIndexParameters(1).vector_longperiod_jM=vector_longperiod_jM;
clear vector_longperiod_jM
ConstituentIndexParameters(1).vector_longperiod_jW=vector_longperiod_jW;
clear vector_longperiod_jW
ConstituentIndexParameters(1).vector_longperiod_jOmega=vector_longperiod_jOmega;
clear vector_longperiod_jOmega
ConstituentIndexParameters(1).vector_diurnal_oneplusdelta_q0=vector_diurnal_oneplusdelta_q0;
clear vector_diurnal_oneplusdelta_q0
ConstituentIndexParameters(1).vector_diurnal_qfactor=vector_diurnal_qfactor;
clear vector_diurnal_qfactor
ConstituentIndexParameters(1).vector_diurnal_jM=vector_diurnal_jM;
clear vector_diurnal_jM
ConstituentIndexParameters(1).vector_diurnal_jW=vector_diurnal_jW;
clear vector_diurnal_jW
ConstituentIndexParameters(1).vector_diurnal_jOmega=vector_diurnal_jOmega;
clear vector_diurnal_jOmega
ConstituentIndexParameters(1).vector_semidiurnal_oneplusdelta_q0=vector_semidiurnal_oneplusdelta_q0;
clear vector_semidiurnal_oneplusdelta_q0
ConstituentIndexParameters(1).vector_semidiurnal_qfactor=vector_semidiurnal_qfactor;
clear vector_semidiurnal_qfactor
ConstituentIndexParameters(1).vector_semidiurnal_jM=vector_semidiurnal_jM;
clear vector_semidiurnal_jM
ConstituentIndexParameters(1).vector_semidiurnal_jW=vector_semidiurnal_jW;
clear vector_semidiurnal_jW
ConstituentIndexParameters(1).vector_semidiurnal_jOmega=vector_semidiurnal_jOmega;
clear vector_semidiurnal_jOmega

clear oneplusdelta_q0_Mf oneplusdelta_q0_Mm qfactor_Mf jM_Mf jM_Mm jW_Mf jW_Mm jOmega_Mf jOmega_Mm oneplusdelta_q0_K1 oneplusdelta_q0_P1 oneplusdelta_q0_Q1 qfactor_K1 qfactor_O1 qfactor_P1 qfactor_Q1 jM_K1 jM_P1 jM_Q1 jW_K1 jW_O1 jW_P1 jW_Q1 jOmega_K1 jOmega_O1 jOmega_P1 jOmega_Q1 oneplusdelta_q0_K2 oneplusdelta_q0_S2 oneplusdelta_q0_N2 qfactor_K2 qfactor_M2 qfactor_S2 qfactor_N2 jM_K2 jM_S2 jM_N2 jW_K2 jW_M2 jW_S2 jW_N2 jOmega_K2 jOmega_M2 jOmega_S2 jOmega_N2
clear oneplusdelta_q0_diurnal_node oneplusdelta_q0_diurnal_LF 
clear oneplusdelta_q0_semidiurnal_node oneplusdelta_q0_semidiurnal_LF 
clear qfactor_diurnal_node qfactor_diurnal_LF 
clear qfactor_semidiurnal_node qfactor_semidiurnal_LF 
clear jM_diurnal_node jM_diurnal_LF 
clear jM_semidiurnal_node jM_semidiurnal_LF 
clear jW_diurnal_node jW_diurnal_LF 
clear jW_semidiurnal_node jW_semidiurnal_LF 
clear jOmega_diurnal_node jOmega_diurnal_LF 
clear jOmega_semidiurnal_node jOmega_semidiurnal_LF 


% clear some constituent index parameters that are unused (I think)

clear oneplusdelta_q0_longperiodconstant qfactor_Mm qfactor_longperiodconstant

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

save parameters_presentday_v9_use_structures_nodeLF.mat EarthMoon_constants PresentDayValues_orbitalparameters ksinchi_vectors ConstituentIndexParameters 
