% Re-run 13 June 2021, after the "v9" version of the parameter structure was 
%   generated

% Also in June 2021:  The variable form of KoverC was implemented

% Update on January 12, 2021:  First experimentation with new lunar
%   Q, k2, CoverCprime, and K/C values, based upon exchanges with 
%          Jim Williams in Jan 2021

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Update on December 23, 2020:  The "tidesinMoon2" codes, which we will use
%   in the paper, were updated to include the different Q values that Jim
%   sent to me in "BRIAN_ARBIC_QUESTIONS_FOR_JIM_WILLIAMS_WITH_WILLIAMS_ANSWERS_DEC_13_2020.docx" ; 
%   we did not bother to update the Q values in the "tidesinMoon3" codes

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% This code tests the equations that were sent to Brian Arbic by Jim Williams 
% in November 2020.  See "Arbic More Moon Tides 112920.docx" which was attached
% to an email on 29 November 2020, and "Arbic Elem Rates 112420.docx" which
% was attached to an email on 24 November 2020

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% For da/dt resulting from tides within the Moon we have the following codes:

% compute_da_dt_tidesinMoon.m :  original code, written 1 December 2017
% compute_da_dt_tidesinMoon2.m : code based upon first formula in 
%                                "Arbic More Moon Tides 112920.docx"
% compute_da_dt_tidesinMoon3.m : code based upon second formula in 
%                                "Arbic More Moon Tides 112920.docx"

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% For deccentricity/dt resulting from tides within the Moon we have the following codes:

% compute_deccentricity_dt_tidesinMoon.m :  original code, written 9 November 2017
% compute_deccentricity_dt_tidesinMoon2.m : code based upon first formula in 
%                                "Arbic More Moon Tides 112920.docx"
% compute_deccentricity_dt_tidesinMoon3.m : code based upon second formula in 
%                                "Arbic More Moon Tides 112920.docx"

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% For dinclination/dt resulting from tides within the Moon we have the following codes:

% compute_dinclination_dt_tidesinMoon.m :  original code, written 1 December 2017
% compute_dinclination_dt_tidesinMoon2.m : code based upon first formula in 
%                                "Arbic More Moon Tides 112920.docx"
% compute_dinclination_dt_tidesinMoon3.m : code based upon second formula in 
%                                "Arbic More Moon Tides 112920.docx"

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Load parameters for the present-day:

load parameters_presentday_v9_use_structures_nodeLF.mat

% Extract present-day parameter and orbital parameter values:

omega_E=PresentDayValues_orbitalparameters.omega_E_presentday;
a=PresentDayValues_orbitalparameters.a_presentday;
inclination=PresentDayValues_orbitalparameters.inclination_presentday;
eccentricity=PresentDayValues_orbitalparameters.eccentricity_presentday;
epsilon=PresentDayValues_orbitalparameters.epsilon_presentday;
n=PresentDayValues_orbitalparameters.n_presentday;


aprime=EarthMoon_constants.aprime;
eccentricityprime=EarthMoon_constants.eccentricityprime;
nprime=EarthMoon_constants.nprime;
G=EarthMoon_constants.G;
k2fluid=EarthMoon_constants.k2fluid;
sfluid=EarthMoon_constants.sfluid;
M_E=EarthMoon_constants.M_E;
R=EarthMoon_constants.R;
C_0=EarthMoon_constants.C_0;
M_S=EarthMoon_constants.M_S;
M_M=EarthMoon_constants.M_M;

beta_tidesinMoon=EarthMoon_constants.beta_tidesinMoon;
k2_over_Q_tidesinMoon=EarthMoon_constants.k2_over_Q_tidesinMoon;

% This is needed for some of the codes:

k2_tidesinMoon=EarthMoon_constants.k2_tidesinMoon;
Q_tidesinMoon=k2_tidesinMoon/k2_over_Q_tidesinMoon;

c=EarthMoon_constants.c;
%KoverC_Moon_coremantledissipation=EarthMoon_constants.KoverC_Moon_coremantledissipation;
CoverCprime_Moon_coremantledissipation=EarthMoon_constants.CoverCprime_Moon_coremantledissipation;
R_M=EarthMoon_constants.R_M;
CovermRsquared_Moon_coremantledissipation=EarthMoon_constants.CovermRsquared_Moon_coremantledissipation;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Compute dOmega_dt, I_lunartilt, KoverC_Moon_coremantledissipation, and xi_Moon_coremantledissipation:

[dOmega_dt] = compute_noderate(nprime,n);

%[I_lunartilt] = compute_lunarequatorialtilt(dOmega_dt,inclination,beta_tidesinMoon,n,c);
[I_lunartilt] = compute_lunarequatorialtilt_WardEquation(dOmega_dt,inclination,n,EarthMoon_constants);

% Check value of I_lunartilt, in degrees:
I_lunartilt*(360/(2*pi))
% answer 1.5704 degrees; Williams writeup says 1.543 degrees

[KoverC_Moon_coremantledissipation,xi_Moon_coremantledissipation] = compute_KoverC_and_xi_lunarCMB(CoverCprime_Moon_coremantledissipation,dOmega_dt,n,I_lunartilt);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% First, we examine dinclination_dt from tides within the Moon:

[dinclination_dt_tidesinMoon,dinclination_dt_Moon_coremantledissipation] = compute_dinclination_dt_tidesinMoon(k2_over_Q_tidesinMoon,M_E,M_M,R_M,a,n,inclination,I_lunartilt,KoverC_Moon_coremantledissipation,xi_Moon_coremantledissipation,CovermRsquared_Moon_coremantledissipation);
% Check values of dinclination_dt, in units of microarcseconds/year:
dinclination_dt_tidesinMoon * ( 10^6 ) * (360/(2*pi))*60*60*( (86400*365.25) )
% answer -0.4931
% Compare to -0.51 microarcseconds per year in Jim Williams comments on 12/31/2020 paper draft
dinclination_dt_Moon_coremantledissipation * ( 10^6 ) * (360/(2*pi))*60*60*( (86400*365.25) )
% answer -0.0429
% Compare to -0.04 microarcseconds per year in Jim Williams comments on 12/31/2020 paper draft

% Add in new (November 2020) computations of dinclination_dt:

clear dinclination_dt_tidesinMoon

[dinclination_dt_tidesinMoon,dinclination_dt_Moon_coremantledissipation] = compute_dinclination_dt_tidesinMoon2(EarthMoon_constants,a,n,eccentricity,inclination,I_lunartilt,KoverC_Moon_coremantledissipation,xi_Moon_coremantledissipation);


% Check values of dinclination_dt, in units of microarcseconds/year:
dinclination_dt_tidesinMoon * ( 10^6 ) * (360/(2*pi))*60*60*( (86400*365.25) )
% answer -0.4587

clear dinclination_dt_tidesinMoon

[dinclination_dt_tidesinMoon,dinclination_dt_Moon_coremantledissipation] = compute_dinclination_dt_tidesinMoon3(k2_tidesinMoon,Q_tidesinMoon,M_E,M_M,R_M,a,n,eccentricity,inclination,I_lunartilt,KoverC_Moon_coremantledissipation,xi_Moon_coremantledissipation,CovermRsquared_Moon_coremantledissipation);

% Check values of dinclination_dt, in units of microarcseconds/year:
dinclination_dt_tidesinMoon * ( 10^6 ) * (360/(2*pi))*60*60*( (86400*365.25) )
% answer -0.4961

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Next, we examine deccentricity_dt from tides within the Moon:

[deccentricity_dt_tidesinMoon] = compute_deccentricity_dt_tidesinMoon(k2_over_Q_tidesinMoon,M_E,M_M,R_M,a,n,eccentricity);
% Check value of deccentricity_dt_tidesinMoon, in units of 1 * 10^-12/year:
deccentricity_dt_tidesinMoon * (10^12) * ( (86400*365.25) )
% answer -6.0248 
  % Compare to -6.9 e-12 per year in Jim Williams comments on 12/31/2020 paper draft, with a 0 contribution from CMB


% Add in new (November 2020) computations of deccentricity_dt:

clear deccentricity_dt_tidesinMoon

[deccentricity_dt_tidesinMoon] = compute_deccentricity_dt_tidesinMoon2(EarthMoon_constants,a,n,eccentricity,inclination,I_lunartilt);


% Check value of deccentricity_dt_tidesinMoon, in units of 1 * 10^-12/year:
deccentricity_dt_tidesinMoon * (10^12) * ( (86400*365.25) )
% answer -5.4936

clear deccentricity_dt_tidesinMoon

[deccentricity_dt_tidesinMoon] = compute_deccentricity_dt_tidesinMoon3(k2_tidesinMoon,Q_tidesinMoon,M_E,M_M,R_M,a,n,eccentricity,inclination,I_lunartilt);

% Check value of deccentricity_dt_tidesinMoon, in units of 1 * 10^-12/year:
deccentricity_dt_tidesinMoon * (10^12) * ( (86400*365.25) )
% answer -6.0629 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Next, we examine da_dt from tides within the Moon:

[da_dt_tidesinMoon,da_dt_Moon_coremantledissipation] = compute_da_dt_tidesinMoon(k2_over_Q_tidesinMoon,M_E,M_M,R_M,a,n,eccentricity,inclination,I_lunartilt,KoverC_Moon_coremantledissipation,xi_Moon_coremantledissipation,CovermRsquared_Moon_coremantledissipation);
% Check value of da_dt, in units of mm/year:
da_dt_tidesinMoon * 1000 * ( (86400*365.25) )
% answer -0.4191
% Compare to -0.471 mm/year in Jim Williams comments on 12/31/2020 paper draft
da_dt_Moon_coremantledissipation * 1000 * ( (86400*365.25) )
% answer -0.0143
  % Compare to -0.015 mm/year in Jim Williams comments on 12/31/2020 paper draft

% Compute dnda in order to convert da_dt to dn_dt:

dnda = compute_dnda(n,a,nprime);

% Check values of dn_dt in units of arcseconds/(century^2):

da_dt_tidesinMoon * dnda * (360/(2*pi))*60*60*( (86400*365.25*100)^2 )
% answer 0.2841
% Compare to Jim Williams November 16 2017 writeup value of 0.210

da_dt_Moon_coremantledissipation * dnda * (360/(2*pi))*60*60*( (86400*365.25*100)^2 )
% answer 0.0097
% Compare to Jim Williams November 16 2017 writeup value of 0.018

% Add in new (November 2020) computations of da_dt:

clear da_dt_tidesinMoon

[da_dt_tidesinMoon,da_dt_Moon_coremantledissipation] = compute_da_dt_tidesinMoon2(EarthMoon_constants,a,n,eccentricity,inclination,I_lunartilt,KoverC_Moon_coremantledissipation,xi_Moon_coremantledissipation);


% Check value of da_dt, in units of mm/year:
da_dt_tidesinMoon * 1000 * ( (86400*365.25) )
% answer -0.3865 

clear da_dt_tidesinMoon

[da_dt_tidesinMoon,da_dt_Moon_coremantledissipation] = compute_da_dt_tidesinMoon3(k2_tidesinMoon,Q_tidesinMoon,M_E,M_M,R_M,a,n,eccentricity,inclination,I_lunartilt,KoverC_Moon_coremantledissipation,xi_Moon_coremantledissipation,CovermRsquared_Moon_coremantledissipation);

% Check value of da_dt, in units of mm/year:
da_dt_tidesinMoon * 1000 * ( (86400*365.25) )
% answer -0.4217

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

